// ============================================================================
// Rocks'n'Diamonds - McDuffin Strikes Back!
// ----------------------------------------------------------------------------
// (c) 1995-2014 by Artsoft Entertainment
//                  Holger Schemel
//                  info@artsoft.org
//                  https://www.artsoft.org/
// ----------------------------------------------------------------------------
// conf_gfx.h
// ============================================================================

// ------- this file was automatically generated -- do not edit by hand -------

#ifndef CONF_GFX_H
#define CONF_GFX_H

// values for graphics configuration (normal elements)

#define IMG_BD_WALL					0
#define IMG_BD_WALL_EDITOR				1
#define IMG_BD_ROCK					2
#define IMG_BD_ROCK_EDITOR				3
#define IMG_BD_ROCK_MOVING_LEFT				4
#define IMG_BD_ROCK_MOVING_RIGHT			5
#define IMG_BD_ROCK_PUSHING_LEFT			6
#define IMG_BD_ROCK_PUSHING_RIGHT			7
#define IMG_BD_DIAMOND					8
#define IMG_BD_DIAMOND_MOVING				9
#define IMG_BD_DIAMOND_FALLING				10
#define IMG_BD_DIAMOND_COLLECTING			11
#define IMG_BD_MAGIC_WALL				12
#define IMG_BD_MAGIC_WALL_ACTIVE			13
#define IMG_BD_MAGIC_WALL_FILLING			14
#define IMG_BD_MAGIC_WALL_FULL				15
#define IMG_BD_MAGIC_WALL_EMPTYING			16
#define IMG_BD_MAGIC_WALL_DEAD				17
#define IMG_BD_AMOEBA					18
#define IMG_BD_AMOEBA_EDITOR				19
#define IMG_BD_BUTTERFLY				20
#define IMG_BD_BUTTERFLY_RIGHT				21
#define IMG_BD_BUTTERFLY_RIGHT_EDITOR			22
#define IMG_BD_BUTTERFLY_UP				23
#define IMG_BD_BUTTERFLY_UP_EDITOR			24
#define IMG_BD_BUTTERFLY_LEFT				25
#define IMG_BD_BUTTERFLY_LEFT_EDITOR			26
#define IMG_BD_BUTTERFLY_DOWN				27
#define IMG_BD_BUTTERFLY_DOWN_EDITOR			28
#define IMG_BD_FIREFLY					29
#define IMG_BD_FIREFLY_RIGHT				30
#define IMG_BD_FIREFLY_RIGHT_EDITOR			31
#define IMG_BD_FIREFLY_UP				32
#define IMG_BD_FIREFLY_UP_EDITOR			33
#define IMG_BD_FIREFLY_LEFT				34
#define IMG_BD_FIREFLY_LEFT_EDITOR			35
#define IMG_BD_FIREFLY_DOWN				36
#define IMG_BD_FIREFLY_DOWN_EDITOR			37
#define IMG_BD_EXPANDABLE_WALL				38
#define IMG_BD_EXPANDABLE_WALL_EDITOR			39
#define IMG_BDX_DEFAULT_EXPLODING			40
#define IMG_BDX_DEFAULT_GROWING				41
#define IMG_BDX_EMPTY_SPACE				42
#define IMG_BDX_PLAYER					43
#define IMG_BDX_PLAYER_DOWN				44
#define IMG_BDX_PLAYER_UP				45
#define IMG_BDX_PLAYER_LEFT				46
#define IMG_BDX_PLAYER_RIGHT				47
#define IMG_BDX_PLAYER_MOVING_DOWN			48
#define IMG_BDX_PLAYER_MOVING_UP			49
#define IMG_BDX_PLAYER_MOVING_LEFT			50
#define IMG_BDX_PLAYER_MOVING_RIGHT			51
#define IMG_BDX_PLAYER_DIGGING_DOWN			52
#define IMG_BDX_PLAYER_DIGGING_UP			53
#define IMG_BDX_PLAYER_DIGGING_LEFT			54
#define IMG_BDX_PLAYER_DIGGING_RIGHT			55
#define IMG_BDX_PLAYER_COLLECTING_DOWN			56
#define IMG_BDX_PLAYER_COLLECTING_UP			57
#define IMG_BDX_PLAYER_COLLECTING_LEFT			58
#define IMG_BDX_PLAYER_COLLECTING_RIGHT			59
#define IMG_BDX_PLAYER_PUSHING_DOWN			60
#define IMG_BDX_PLAYER_PUSHING_UP			61
#define IMG_BDX_PLAYER_PUSHING_LEFT			62
#define IMG_BDX_PLAYER_PUSHING_RIGHT			63
#define IMG_BDX_PLAYER_SNAPPING_DOWN			64
#define IMG_BDX_PLAYER_SNAPPING_UP			65
#define IMG_BDX_PLAYER_SNAPPING_LEFT			66
#define IMG_BDX_PLAYER_SNAPPING_RIGHT			67
#define IMG_BDX_PLAYER_GLUED				68
#define IMG_BDX_PLAYER_GLUED_EDITOR			69
#define IMG_BDX_PLAYER_WITH_BOMB			70
#define IMG_BDX_PLAYER_WITH_BOMB_TURNING		71
#define IMG_BDX_PLAYER_WITH_ROCKET_LAUNCHER		72
#define IMG_BDX_PLAYER_WITH_ROCKET_LAUNCHER_TURNING	73
#define IMG_BDX_PLAYER_STIRRING				74
#define IMG_BDX_WALL					75
#define IMG_BDX_WALL_EDITOR				76
#define IMG_BDX_ROCK					77
#define IMG_BDX_ROCK_EDITOR				78
#define IMG_BDX_ROCK_MOVING_LEFT			79
#define IMG_BDX_ROCK_MOVING_RIGHT			80
#define IMG_BDX_ROCK_PUSHING_LEFT			81
#define IMG_BDX_ROCK_PUSHING_RIGHT			82
#define IMG_BDX_ROCK_FALLING_EDITOR			83
#define IMG_BDX_DIAMOND					84
#define IMG_BDX_DIAMOND_MOVING				85
#define IMG_BDX_DIAMOND_FALLING				86
#define IMG_BDX_DIAMOND_COLLECTING			87
#define IMG_BDX_DIAMOND_FALLING_EDITOR			88
#define IMG_BDX_MAGIC_WALL				89
#define IMG_BDX_MAGIC_WALL_ACTIVE			90
#define IMG_BDX_AMOEBA_1				91
#define IMG_BDX_AMOEBA_2				92
#define IMG_BDX_BUTTERFLY_1				93
#define IMG_BDX_BUTTERFLY_1_RIGHT			94
#define IMG_BDX_BUTTERFLY_1_RIGHT_EDITOR		95
#define IMG_BDX_BUTTERFLY_1_UP				96
#define IMG_BDX_BUTTERFLY_1_UP_EDITOR			97
#define IMG_BDX_BUTTERFLY_1_LEFT			98
#define IMG_BDX_BUTTERFLY_1_LEFT_EDITOR			99
#define IMG_BDX_BUTTERFLY_1_DOWN			100
#define IMG_BDX_BUTTERFLY_1_DOWN_EDITOR			101
#define IMG_BDX_BUTTERFLY_2				102
#define IMG_BDX_BUTTERFLY_2_RIGHT			103
#define IMG_BDX_BUTTERFLY_2_RIGHT_EDITOR		104
#define IMG_BDX_BUTTERFLY_2_UP				105
#define IMG_BDX_BUTTERFLY_2_UP_EDITOR			106
#define IMG_BDX_BUTTERFLY_2_LEFT			107
#define IMG_BDX_BUTTERFLY_2_LEFT_EDITOR			108
#define IMG_BDX_BUTTERFLY_2_DOWN			109
#define IMG_BDX_BUTTERFLY_2_DOWN_EDITOR			110
#define IMG_BDX_FIREFLY_1				111
#define IMG_BDX_FIREFLY_1_RIGHT				112
#define IMG_BDX_FIREFLY_1_RIGHT_EDITOR			113
#define IMG_BDX_FIREFLY_1_UP				114
#define IMG_BDX_FIREFLY_1_UP_EDITOR			115
#define IMG_BDX_FIREFLY_1_LEFT				116
#define IMG_BDX_FIREFLY_1_LEFT_EDITOR			117
#define IMG_BDX_FIREFLY_1_DOWN				118
#define IMG_BDX_FIREFLY_1_DOWN_EDITOR			119
#define IMG_BDX_FIREFLY_2				120
#define IMG_BDX_FIREFLY_2_RIGHT				121
#define IMG_BDX_FIREFLY_2_RIGHT_EDITOR			122
#define IMG_BDX_FIREFLY_2_UP				123
#define IMG_BDX_FIREFLY_2_UP_EDITOR			124
#define IMG_BDX_FIREFLY_2_LEFT				125
#define IMG_BDX_FIREFLY_2_LEFT_EDITOR			126
#define IMG_BDX_FIREFLY_2_DOWN				127
#define IMG_BDX_FIREFLY_2_DOWN_EDITOR			128
#define IMG_BDX_SAND					129
#define IMG_BDX_SAND_CRUMBLED				130
#define IMG_BDX_SAND_DIGGING_LEFT			131
#define IMG_BDX_SAND_DIGGING_RIGHT			132
#define IMG_BDX_SAND_DIGGING_UP				133
#define IMG_BDX_SAND_DIGGING_DOWN			134
#define IMG_BDX_SAND_DIGGING_LEFT_CRUMBLED		135
#define IMG_BDX_SAND_DIGGING_RIGHT_CRUMBLED		136
#define IMG_BDX_SAND_DIGGING_UP_CRUMBLED		137
#define IMG_BDX_SAND_DIGGING_DOWN_CRUMBLED		138
#define IMG_BDX_GRASS					139
#define IMG_BDX_GRASS_CRUMBLED				140
#define IMG_BDX_GRASS_DIGGING_LEFT			141
#define IMG_BDX_GRASS_DIGGING_RIGHT			142
#define IMG_BDX_GRASS_DIGGING_UP			143
#define IMG_BDX_GRASS_DIGGING_DOWN			144
#define IMG_BDX_GRASS_DIGGING_LEFT_CRUMBLED		145
#define IMG_BDX_GRASS_DIGGING_RIGHT_CRUMBLED		146
#define IMG_BDX_GRASS_DIGGING_UP_CRUMBLED		147
#define IMG_BDX_GRASS_DIGGING_DOWN_CRUMBLED		148
#define IMG_BDX_GRASS_BALL				149
#define IMG_BDX_GRASS_BALL_FALLING_EDITOR		150
#define IMG_BDX_GRASS_LOOSE				151
#define IMG_BDX_GRASS_LOOSE_FALLING_EDITOR		152
#define IMG_BDX_SAND_SLOPED_UP_LEFT			153
#define IMG_BDX_SAND_SLOPED_UP_LEFT_CRUMBLED		154
#define IMG_BDX_SAND_SLOPED_UP_RIGHT			155
#define IMG_BDX_SAND_SLOPED_UP_RIGHT_CRUMBLED		156
#define IMG_BDX_SAND_SLOPED_DOWN_LEFT			157
#define IMG_BDX_SAND_SLOPED_DOWN_LEFT_CRUMBLED		158
#define IMG_BDX_SAND_SLOPED_DOWN_RIGHT			159
#define IMG_BDX_SAND_SLOPED_DOWN_RIGHT_CRUMBLED		160
#define IMG_BDX_SAND_GLUED				161
#define IMG_BDX_SAND_GLUED_CRUMBLED			162
#define IMG_BDX_SAND_GLUED_EDITOR			163
#define IMG_BDX_WALL_SLOPED_UP_LEFT			164
#define IMG_BDX_WALL_SLOPED_UP_RIGHT			165
#define IMG_BDX_WALL_SLOPED_DOWN_LEFT			166
#define IMG_BDX_WALL_SLOPED_DOWN_RIGHT			167
#define IMG_BDX_WALL_NON_SLOPED				168
#define IMG_BDX_WALL_NON_SLOPED_EDITOR			169
#define IMG_BDX_WALL_DIGGABLE				170
#define IMG_BDX_WALL_DIGGABLE_EDITOR			171
#define IMG_BDX_WALL_DIAMOND				172
#define IMG_BDX_WALL_DIAMOND_EDITOR			173
#define IMG_BDX_WALL_KEY_1				174
#define IMG_BDX_WALL_KEY_1_EDITOR			175
#define IMG_BDX_WALL_KEY_2				176
#define IMG_BDX_WALL_KEY_2_EDITOR			177
#define IMG_BDX_WALL_KEY_3				178
#define IMG_BDX_WALL_KEY_3_EDITOR			179
#define IMG_BDX_FALLING_WALL				180
#define IMG_BDX_FALLING_WALL_EDITOR			181
#define IMG_BDX_FALLING_WALL_FALLING_EDITOR		182
#define IMG_BDX_STEELWALL				183
#define IMG_BDX_STEELWALL_SLOPED_UP_LEFT		184
#define IMG_BDX_STEELWALL_SLOPED_UP_RIGHT		185
#define IMG_BDX_STEELWALL_SLOPED_DOWN_LEFT		186
#define IMG_BDX_STEELWALL_SLOPED_DOWN_RIGHT		187
#define IMG_BDX_STEELWALL_EXPLODABLE			188
#define IMG_BDX_STEELWALL_EXPLODABLE_EDITOR		189
#define IMG_BDX_STEELWALL_DIGGABLE			190
#define IMG_BDX_STEELWALL_DIGGABLE_EDITOR		191
#define IMG_BDX_EXPANDABLE_WALL_HORIZONTAL		192
#define IMG_BDX_EXPANDABLE_WALL_HORIZONTAL_EDITOR	193
#define IMG_BDX_EXPANDABLE_WALL_VERTICAL		194
#define IMG_BDX_EXPANDABLE_WALL_VERTICAL_EDITOR		195
#define IMG_BDX_EXPANDABLE_WALL_ANY			196
#define IMG_BDX_EXPANDABLE_WALL_ANY_EDITOR		197
#define IMG_BDX_EXPANDABLE_STEELWALL_HORIZONTAL		198
#define IMG_BDX_EXPANDABLE_STEELWALL_HORIZONTAL_EDITOR	199
#define IMG_BDX_EXPANDABLE_STEELWALL_VERTICAL		200
#define IMG_BDX_EXPANDABLE_STEELWALL_VERTICAL_EDITOR	201
#define IMG_BDX_EXPANDABLE_STEELWALL_ANY		202
#define IMG_BDX_EXPANDABLE_STEELWALL_ANY_EDITOR		203
#define IMG_BDX_EXPANDABLE_WALL_SWITCH			204
#define IMG_BDX_EXPANDABLE_WALL_SWITCH_ACTIVE		205
#define IMG_BDX_INBOX					206
#define IMG_BDX_INBOX_OPENING				207
#define IMG_BDX_INBOX_EDITOR				208
#define IMG_BDX_EXIT_CLOSED				209
#define IMG_BDX_EXIT_CLOSED_EDITOR			210
#define IMG_BDX_EXIT_OPEN				211
#define IMG_BDX_EXIT_OPEN_EDITOR			212
#define IMG_BDX_STEEL_EXIT_CLOSED			213
#define IMG_BDX_STEEL_EXIT_CLOSED_EDITOR		214
#define IMG_BDX_STEEL_EXIT_OPEN				215
#define IMG_BDX_STEEL_EXIT_OPEN_EDITOR			216
#define IMG_BDX_INVISIBLE_EXIT_CLOSED			217
#define IMG_BDX_INVISIBLE_EXIT_CLOSED_EDITOR		218
#define IMG_BDX_INVISIBLE_EXIT_OPEN			219
#define IMG_BDX_INVISIBLE_EXIT_OPEN_EDITOR		220
#define IMG_BDX_INVISIBLE_STEEL_EXIT_CLOSED		221
#define IMG_BDX_INVISIBLE_STEEL_EXIT_CLOSED_EDITOR	222
#define IMG_BDX_INVISIBLE_STEEL_EXIT_OPEN		223
#define IMG_BDX_INVISIBLE_STEEL_EXIT_OPEN_EDITOR	224
#define IMG_BDX_FLYING_ROCK				225
#define IMG_BDX_FLYING_ROCK_FLYING_EDITOR		226
#define IMG_BDX_HEAVY_ROCK				227
#define IMG_BDX_HEAVY_ROCK_FALLING_EDITOR		228
#define IMG_BDX_LIGHT_ROCK				229
#define IMG_BDX_LIGHT_ROCK_FALLING_EDITOR		230
#define IMG_BDX_ROCK_GLUED				231
#define IMG_BDX_ROCK_GLUED_EDITOR			232
#define IMG_BDX_FLYING_DIAMOND				233
#define IMG_BDX_FLYING_DIAMOND_MOVING			234
#define IMG_BDX_FLYING_DIAMOND_FLYING			235
#define IMG_BDX_FLYING_DIAMOND_FLYING_EDITOR		236
#define IMG_BDX_DIAMOND_GLUED				237
#define IMG_BDX_DIAMOND_GLUED_EDITOR			238
#define IMG_BDX_DIAMOND_KEY				239
#define IMG_BDX_TRAPPED_DIAMOND				240
#define IMG_BDX_NUT					241
#define IMG_BDX_NUT_BREAKING				242
#define IMG_BDX_NUT_FALLING_EDITOR			243
#define IMG_BDX_BUBBLE					244
#define IMG_BDX_TRAPPED_BUBBLE				245
#define IMG_BDX_CREATURE_SWITCH				246
#define IMG_BDX_CREATURE_SWITCH_ACTIVE			247
#define IMG_BDX_BITER_SWITCH_1				248
#define IMG_BDX_BITER_SWITCH_1_CRUMBLED			249
#define IMG_BDX_BITER_SWITCH_2				250
#define IMG_BDX_BITER_SWITCH_2_CRUMBLED			251
#define IMG_BDX_BITER_SWITCH_3				252
#define IMG_BDX_BITER_SWITCH_3_CRUMBLED			253
#define IMG_BDX_BITER_SWITCH_4				254
#define IMG_BDX_BITER_SWITCH_4_CRUMBLED			255
#define IMG_BDX_REPLICATOR				256
#define IMG_BDX_REPLICATOR_ACTIVE			257
#define IMG_BDX_REPLICATOR_SWITCH			258
#define IMG_BDX_REPLICATOR_SWITCH_ACTIVE		259
#define IMG_BDX_CONVEYOR_LEFT				260
#define IMG_BDX_CONVEYOR_LEFT_EDITOR			261
#define IMG_BDX_CONVEYOR_LEFT_ACTIVE			262
#define IMG_BDX_CONVEYOR_RIGHT				263
#define IMG_BDX_CONVEYOR_RIGHT_EDITOR			264
#define IMG_BDX_CONVEYOR_RIGHT_ACTIVE			265
#define IMG_BDX_CONVEYOR_SWITCH				266
#define IMG_BDX_CONVEYOR_SWITCH_ACTIVE			267
#define IMG_BDX_CONVEYOR_DIR_SWITCH			268
#define IMG_BDX_CONVEYOR_DIR_SWITCH_ACTIVE		269
#define IMG_BDX_GRAVITY_SWITCH				270
#define IMG_BDX_GRAVITY_SWITCH_ACTIVE			271
#define IMG_BDX_ACID					272
#define IMG_BDX_BOX					273
#define IMG_BDX_TIME_PENALTY				274
#define IMG_BDX_TIME_PENALTY_EDITOR			275
#define IMG_BDX_GRAVESTONE				276
#define IMG_BDX_CLOCK					277
#define IMG_BDX_POT					278
#define IMG_BDX_PNEUMATIC_HAMMER			279
#define IMG_BDX_PNEUMATIC_HAMMER_HITTING_LEFT		280
#define IMG_BDX_PNEUMATIC_HAMMER_HITTING_RIGHT		281
#define IMG_BDX_PLAYER_HITTING_LEFT			282
#define IMG_BDX_PLAYER_HITTING_RIGHT			283
#define IMG_BDX_TELEPORTER				284
#define IMG_BDX_SKELETON				285
#define IMG_BDX_WATER					286
#define IMG_BDX_KEY_1					287
#define IMG_BDX_KEY_2					288
#define IMG_BDX_KEY_3					289
#define IMG_BDX_GATE_1					290
#define IMG_BDX_GATE_2					291
#define IMG_BDX_GATE_3					292
#define IMG_BDX_LAVA					293
#define IMG_BDX_SWEET					294
#define IMG_BDX_VOODOO_DOLL				295
#define IMG_BDX_SLIME					296
#define IMG_BDX_WAITING_ROCK				297
#define IMG_BDX_WAITING_ROCK_EDITOR			298
#define IMG_BDX_CHASING_ROCK				299
#define IMG_BDX_GHOST					300
#define IMG_BDX_COW					301
#define IMG_BDX_COW_LEFT				302
#define IMG_BDX_COW_LEFT_EDITOR				303
#define IMG_BDX_COW_UP					304
#define IMG_BDX_COW_UP_EDITOR				305
#define IMG_BDX_COW_RIGHT				306
#define IMG_BDX_COW_RIGHT_EDITOR			307
#define IMG_BDX_COW_DOWN				308
#define IMG_BDX_COW_DOWN_EDITOR				309
#define IMG_BDX_COW_ENCLOSED_1_EDITOR			310
#define IMG_BDX_COW_ENCLOSED_2_EDITOR			311
#define IMG_BDX_COW_ENCLOSED_3_EDITOR			312
#define IMG_BDX_COW_ENCLOSED_4_EDITOR			313
#define IMG_BDX_COW_ENCLOSED_5_EDITOR			314
#define IMG_BDX_COW_ENCLOSED_6_EDITOR			315
#define IMG_BDX_COW_ENCLOSED_7_EDITOR			316
#define IMG_BDX_STONEFLY				317
#define IMG_BDX_STONEFLY_RIGHT				318
#define IMG_BDX_STONEFLY_RIGHT_EDITOR			319
#define IMG_BDX_STONEFLY_UP				320
#define IMG_BDX_STONEFLY_UP_EDITOR			321
#define IMG_BDX_STONEFLY_LEFT				322
#define IMG_BDX_STONEFLY_LEFT_EDITOR			323
#define IMG_BDX_STONEFLY_DOWN				324
#define IMG_BDX_STONEFLY_DOWN_EDITOR			325
#define IMG_BDX_BITER					326
#define IMG_BDX_BITER_LEFT				327
#define IMG_BDX_BITER_LEFT_EDITOR			328
#define IMG_BDX_BITER_RIGHT				329
#define IMG_BDX_BITER_RIGHT_EDITOR			330
#define IMG_BDX_BITER_UP				331
#define IMG_BDX_BITER_UP_EDITOR				332
#define IMG_BDX_BITER_DOWN				333
#define IMG_BDX_BITER_DOWN_EDITOR			334
#define IMG_BDX_BITER_MOVING				335
#define IMG_BDX_DRAGONFLY				336
#define IMG_BDX_DRAGONFLY_RIGHT				337
#define IMG_BDX_DRAGONFLY_RIGHT_EDITOR			338
#define IMG_BDX_DRAGONFLY_UP				339
#define IMG_BDX_DRAGONFLY_UP_EDITOR			340
#define IMG_BDX_DRAGONFLY_LEFT				341
#define IMG_BDX_DRAGONFLY_LEFT_EDITOR			342
#define IMG_BDX_DRAGONFLY_DOWN				343
#define IMG_BDX_DRAGONFLY_DOWN_EDITOR			344
#define IMG_BDX_BOMB					345
#define IMG_BDX_BOMB_ACTIVE				346
#define IMG_BDX_ROCKET_LAUNCHER				347
#define IMG_BDX_ROCKET					348
#define IMG_BDX_ROCKET_RIGHT				349
#define IMG_BDX_ROCKET_UP				350
#define IMG_BDX_ROCKET_LEFT				351
#define IMG_BDX_ROCKET_DOWN				352
#define IMG_BDX_NITRO_PACK				353
#define IMG_BDX_NITRO_PACK_FALLING_EDITOR		354
#define IMG_BDX_NITRO_PACK_EXPLODING_EDITOR		355
#define IMG_BDX_FAKE_BONUS				356
#define IMG_BDX_COVERED					357
#define IMG_SP_DEFAULT_EXPLODING			358
#define IMG_SP_EMPTY_SPACE				359
#define IMG_SP_ZONK					360
#define IMG_SP_ZONK_MOVING_LEFT				361
#define IMG_SP_ZONK_MOVING_RIGHT			362
#define IMG_SP_ZONK_PUSHING_LEFT			363
#define IMG_SP_ZONK_PUSHING_RIGHT			364
#define IMG_SP_BASE					365
#define IMG_SP_BASE_DIGGING				366
#define IMG_SP_BASE_SNAPPING				367
#define IMG_SP_MURPHY					368
#define IMG_SP_MURPHY_MOVING_LEFT			369
#define IMG_SP_MURPHY_MOVING_RIGHT			370
#define IMG_SP_MURPHY_DIGGING_LEFT			371
#define IMG_SP_MURPHY_DIGGING_RIGHT			372
#define IMG_SP_MURPHY_COLLECTING_LEFT			373
#define IMG_SP_MURPHY_COLLECTING_RIGHT			374
#define IMG_SP_MURPHY_PUSHING_LEFT			375
#define IMG_SP_MURPHY_PUSHING_RIGHT			376
#define IMG_SP_MURPHY_SNAPPING_LEFT			377
#define IMG_SP_MURPHY_SNAPPING_RIGHT			378
#define IMG_SP_MURPHY_SNAPPING_UP			379
#define IMG_SP_MURPHY_SNAPPING_DOWN			380
#define IMG_SP_MURPHY_BORING				381
#define IMG_SP_MURPHY_BORING_1				382
#define IMG_SP_MURPHY_SLEEPING_LEFT			383
#define IMG_SP_MURPHY_SLEEPING_RIGHT			384
#define IMG_SP_MURPHY_DROPPING				385
#define IMG_SP_MURPHY_SHRINKING				386
#define IMG_SP_MURPHY_CLONE				387
#define IMG_SP_INFOTRON					388
#define IMG_SP_INFOTRON_EDITOR				389
#define IMG_SP_INFOTRON_MOVING_LEFT			390
#define IMG_SP_INFOTRON_MOVING_RIGHT			391
#define IMG_SP_INFOTRON_COLLECTING			392
#define IMG_SP_CHIP_SINGLE				393
#define IMG_SP_CHIP_LEFT				394
#define IMG_SP_CHIP_RIGHT				395
#define IMG_SP_CHIP_TOP					396
#define IMG_SP_CHIP_BOTTOM				397
#define IMG_SP_HARDWARE_GRAY				398
#define IMG_SP_HARDWARE_GREEN				399
#define IMG_SP_HARDWARE_BLUE				400
#define IMG_SP_HARDWARE_RED				401
#define IMG_SP_HARDWARE_YELLOW				402
#define IMG_SP_EXIT_CLOSED				403
#define IMG_SP_EXIT_OPENING				404
#define IMG_SP_EXIT_OPEN				405
#define IMG_SP_EXIT_CLOSING				406
#define IMG_SP_DISK_ORANGE				407
#define IMG_SP_DISK_YELLOW				408
#define IMG_SP_DISK_RED					409
#define IMG_SP_DISK_RED_COLLECTING			410
#define IMG_SP_DISK_RED_ACTIVE				411
#define IMG_SP_PORT_RIGHT				412
#define IMG_SP_PORT_DOWN				413
#define IMG_SP_PORT_LEFT				414
#define IMG_SP_PORT_UP					415
#define IMG_SP_PORT_HORIZONTAL				416
#define IMG_SP_PORT_VERTICAL				417
#define IMG_SP_PORT_ANY					418
#define IMG_SP_GRAVITY_PORT_RIGHT			419
#define IMG_SP_GRAVITY_PORT_RIGHT_EDITOR		420
#define IMG_SP_GRAVITY_PORT_DOWN			421
#define IMG_SP_GRAVITY_PORT_DOWN_EDITOR			422
#define IMG_SP_GRAVITY_PORT_LEFT			423
#define IMG_SP_GRAVITY_PORT_LEFT_EDITOR			424
#define IMG_SP_GRAVITY_PORT_UP				425
#define IMG_SP_GRAVITY_PORT_UP_EDITOR			426
#define IMG_SP_GRAVITY_ON_PORT_RIGHT			427
#define IMG_SP_GRAVITY_ON_PORT_RIGHT_EDITOR		428
#define IMG_SP_GRAVITY_ON_PORT_DOWN			429
#define IMG_SP_GRAVITY_ON_PORT_DOWN_EDITOR		430
#define IMG_SP_GRAVITY_ON_PORT_LEFT			431
#define IMG_SP_GRAVITY_ON_PORT_LEFT_EDITOR		432
#define IMG_SP_GRAVITY_ON_PORT_UP			433
#define IMG_SP_GRAVITY_ON_PORT_UP_EDITOR		434
#define IMG_SP_GRAVITY_OFF_PORT_RIGHT			435
#define IMG_SP_GRAVITY_OFF_PORT_RIGHT_EDITOR		436
#define IMG_SP_GRAVITY_OFF_PORT_DOWN			437
#define IMG_SP_GRAVITY_OFF_PORT_DOWN_EDITOR		438
#define IMG_SP_GRAVITY_OFF_PORT_LEFT			439
#define IMG_SP_GRAVITY_OFF_PORT_LEFT_EDITOR		440
#define IMG_SP_GRAVITY_OFF_PORT_UP			441
#define IMG_SP_GRAVITY_OFF_PORT_UP_EDITOR		442
#define IMG_SP_SNIKSNAK					443
#define IMG_SP_SNIKSNAK_LEFT				444
#define IMG_SP_SNIKSNAK_RIGHT				445
#define IMG_SP_SNIKSNAK_UP				446
#define IMG_SP_SNIKSNAK_DOWN				447
#define IMG_SP_SNIKSNAK_TURNING_FROM_LEFT_UP		448
#define IMG_SP_SNIKSNAK_TURNING_FROM_LEFT_DOWN		449
#define IMG_SP_SNIKSNAK_TURNING_FROM_RIGHT_UP		450
#define IMG_SP_SNIKSNAK_TURNING_FROM_RIGHT_DOWN		451
#define IMG_SP_SNIKSNAK_TURNING_FROM_UP_LEFT		452
#define IMG_SP_SNIKSNAK_TURNING_FROM_UP_RIGHT		453
#define IMG_SP_SNIKSNAK_TURNING_FROM_DOWN_LEFT		454
#define IMG_SP_SNIKSNAK_TURNING_FROM_DOWN_RIGHT		455
#define IMG_SP_ELECTRON					456
#define IMG_SP_ELECTRON_EDITOR				457
#define IMG_SP_ELECTRON_EXPLODING			458
#define IMG_SP_TERMINAL					459
#define IMG_SP_TERMINAL_EDITOR				460
#define IMG_SP_TERMINAL_ACTIVE				461
#define IMG_SP_BUGGY_BASE				462
#define IMG_SP_BUGGY_BASE_EDITOR			463
#define IMG_SP_BUGGY_BASE_ACTIVATING			464
#define IMG_SP_BUGGY_BASE_ACTIVE			465
#define IMG_SP_HARDWARE_BASE_1				466
#define IMG_SP_HARDWARE_BASE_2				467
#define IMG_SP_HARDWARE_BASE_3				468
#define IMG_SP_HARDWARE_BASE_4				469
#define IMG_SP_HARDWARE_BASE_5				470
#define IMG_SP_HARDWARE_BASE_6				471
#define IMG_SOKOBAN_OBJECT				472
#define IMG_SOKOBAN_FIELD_EMPTY				473
#define IMG_SOKOBAN_FIELD_FULL				474
#define IMG_SOKOBAN_FIELD_PLAYER			475
#define IMG_EMPTY_SPACE					476
#define IMG_SAND					477
#define IMG_SAND_CRUMBLED				478
#define IMG_SAND_DIGGING_LEFT				479
#define IMG_SAND_DIGGING_RIGHT				480
#define IMG_SAND_DIGGING_UP				481
#define IMG_SAND_DIGGING_DOWN				482
#define IMG_SAND_DIGGING_LEFT_CRUMBLED			483
#define IMG_SAND_DIGGING_RIGHT_CRUMBLED			484
#define IMG_SAND_DIGGING_UP_CRUMBLED			485
#define IMG_SAND_DIGGING_DOWN_CRUMBLED			486
#define IMG_WALL					487
#define IMG_WALL_SLIPPERY				488
#define IMG_STEELWALL					489
#define IMG_ROCK					490
#define IMG_ROCK_MOVING_LEFT				491
#define IMG_ROCK_MOVING_RIGHT				492
#define IMG_ROCK_PUSHING_LEFT				493
#define IMG_ROCK_PUSHING_RIGHT				494
#define IMG_EMERALD					495
#define IMG_EMERALD_MOVING				496
#define IMG_EMERALD_FALLING				497
#define IMG_EMERALD_COLLECTING				498
#define IMG_DIAMOND					499
#define IMG_DIAMOND_MOVING				500
#define IMG_DIAMOND_FALLING				501
#define IMG_DIAMOND_COLLECTING				502
#define IMG_BOMB					503
#define IMG_NUT						504
#define IMG_NUT_BREAKING				505
#define IMG_DYNAMITE					506
#define IMG_DYNAMITE_ACTIVE				507
#define IMG_DYNAMITE_COLLECTING				508
#define IMG_EM_DYNAMITE					509
#define IMG_EM_DYNAMITE_ACTIVE				510
#define IMG_EM_DYNAMITE_ACTIVE_EDITOR			511
#define IMG_EM_DYNAMITE_COLLECTING			512
#define IMG_WALL_EMERALD				513
#define IMG_WALL_DIAMOND				514
#define IMG_BUG						515
#define IMG_BUG_RIGHT					516
#define IMG_BUG_UP					517
#define IMG_BUG_LEFT					518
#define IMG_BUG_DOWN					519
#define IMG_BUG_MOVING_RIGHT				520
#define IMG_BUG_MOVING_UP				521
#define IMG_BUG_MOVING_LEFT				522
#define IMG_BUG_MOVING_DOWN				523
#define IMG_BUG_TURNING_FROM_RIGHT_UP			524
#define IMG_BUG_TURNING_FROM_UP_LEFT			525
#define IMG_BUG_TURNING_FROM_LEFT_DOWN			526
#define IMG_BUG_TURNING_FROM_DOWN_RIGHT			527
#define IMG_BUG_TURNING_FROM_RIGHT_DOWN			528
#define IMG_BUG_TURNING_FROM_UP_RIGHT			529
#define IMG_BUG_TURNING_FROM_LEFT_UP			530
#define IMG_BUG_TURNING_FROM_DOWN_LEFT			531
#define IMG_SPACESHIP					532
#define IMG_SPACESHIP_RIGHT				533
#define IMG_SPACESHIP_UP				534
#define IMG_SPACESHIP_LEFT				535
#define IMG_SPACESHIP_DOWN				536
#define IMG_SPACESHIP_MOVING_RIGHT			537
#define IMG_SPACESHIP_MOVING_UP				538
#define IMG_SPACESHIP_MOVING_LEFT			539
#define IMG_SPACESHIP_MOVING_DOWN			540
#define IMG_SPACESHIP_TURNING_FROM_RIGHT_UP		541
#define IMG_SPACESHIP_TURNING_FROM_UP_LEFT		542
#define IMG_SPACESHIP_TURNING_FROM_LEFT_DOWN		543
#define IMG_SPACESHIP_TURNING_FROM_DOWN_RIGHT		544
#define IMG_SPACESHIP_TURNING_FROM_RIGHT_DOWN		545
#define IMG_SPACESHIP_TURNING_FROM_UP_RIGHT		546
#define IMG_SPACESHIP_TURNING_FROM_LEFT_UP		547
#define IMG_SPACESHIP_TURNING_FROM_DOWN_LEFT		548
#define IMG_YAMYAM					549
#define IMG_YAMYAM_LEFT					550
#define IMG_YAMYAM_LEFT_EDITOR				551
#define IMG_YAMYAM_RIGHT				552
#define IMG_YAMYAM_RIGHT_EDITOR				553
#define IMG_YAMYAM_UP					554
#define IMG_YAMYAM_UP_EDITOR				555
#define IMG_YAMYAM_DOWN					556
#define IMG_YAMYAM_DOWN_EDITOR				557
#define IMG_YAMYAM_MOVING				558
#define IMG_ROBOT					559
#define IMG_ROBOT_MOVING				560
#define IMG_ROBOT_WHEEL					561
#define IMG_ROBOT_WHEEL_ACTIVE				562
#define IMG_MAGIC_WALL					563
#define IMG_MAGIC_WALL_ACTIVE				564
#define IMG_MAGIC_WALL_FILLING				565
#define IMG_MAGIC_WALL_FULL				566
#define IMG_MAGIC_WALL_EMPTYING				567
#define IMG_MAGIC_WALL_DEAD				568
#define IMG_DC_MAGIC_WALL				569
#define IMG_DC_MAGIC_WALL_ACTIVE			570
#define IMG_DC_MAGIC_WALL_FILLING			571
#define IMG_DC_MAGIC_WALL_FULL				572
#define IMG_DC_MAGIC_WALL_EMPTYING			573
#define IMG_DC_MAGIC_WALL_DEAD				574
#define IMG_QUICKSAND_EMPTY				575
#define IMG_QUICKSAND_FILLING				576
#define IMG_QUICKSAND_FULL				577
#define IMG_QUICKSAND_FULL_EDITOR			578
#define IMG_QUICKSAND_EMPTYING				579
#define IMG_QUICKSAND_FAST_EMPTY			580
#define IMG_QUICKSAND_FAST_FILLING			581
#define IMG_QUICKSAND_FAST_FULL				582
#define IMG_QUICKSAND_FAST_FULL_EDITOR			583
#define IMG_QUICKSAND_FAST_EMPTYING			584
#define IMG_ACID_POOL_TOPLEFT				585
#define IMG_ACID_POOL_TOPRIGHT				586
#define IMG_ACID_POOL_BOTTOMLEFT			587
#define IMG_ACID_POOL_BOTTOM				588
#define IMG_ACID_POOL_BOTTOMRIGHT			589
#define IMG_ACID					590
#define IMG_ACID_SPLASH_LEFT				591
#define IMG_ACID_SPLASH_RIGHT				592
#define IMG_AMOEBA_DROP					593
#define IMG_AMOEBA_GROWING				594
#define IMG_AMOEBA_SHRINKING				595
#define IMG_AMOEBA_WET					596
#define IMG_AMOEBA_WET_EDITOR				597
#define IMG_AMOEBA_DROPPING				598
#define IMG_AMOEBA_DRY					599
#define IMG_AMOEBA_FULL					600
#define IMG_AMOEBA_FULL_EDITOR				601
#define IMG_AMOEBA_DEAD					602
#define IMG_AMOEBA_DEAD_EDITOR				603
#define IMG_EM_KEY_1					604
#define IMG_EM_KEY_1_COLLECTING				605
#define IMG_EM_KEY_2					606
#define IMG_EM_KEY_2_COLLECTING				607
#define IMG_EM_KEY_3					608
#define IMG_EM_KEY_3_COLLECTING				609
#define IMG_EM_KEY_4					610
#define IMG_EM_KEY_4_COLLECTING				611
#define IMG_DC_KEY_WHITE				612
#define IMG_DC_KEY_WHITE_COLLECTING			613
#define IMG_EM_GATE_1					614
#define IMG_EM_GATE_2					615
#define IMG_EM_GATE_3					616
#define IMG_EM_GATE_4					617
#define IMG_DC_GATE_WHITE				618
#define IMG_EM_GATE_1_GRAY				619
#define IMG_EM_GATE_1_GRAY_EDITOR			620
#define IMG_EM_GATE_1_GRAY_ACTIVE			621
#define IMG_EM_GATE_2_GRAY				622
#define IMG_EM_GATE_2_GRAY_EDITOR			623
#define IMG_EM_GATE_2_GRAY_ACTIVE			624
#define IMG_EM_GATE_3_GRAY				625
#define IMG_EM_GATE_3_GRAY_EDITOR			626
#define IMG_EM_GATE_3_GRAY_ACTIVE			627
#define IMG_EM_GATE_4_GRAY				628
#define IMG_EM_GATE_4_GRAY_EDITOR			629
#define IMG_EM_GATE_4_GRAY_ACTIVE			630
#define IMG_DC_GATE_WHITE_GRAY				631
#define IMG_DC_GATE_WHITE_GRAY_EDITOR			632
#define IMG_DC_GATE_WHITE_GRAY_ACTIVE			633
#define IMG_DC_GATE_FAKE_GRAY				634
#define IMG_EXIT_CLOSED					635
#define IMG_EXIT_OPENING				636
#define IMG_EXIT_OPEN					637
#define IMG_EXIT_CLOSING				638
#define IMG_STEEL_EXIT_CLOSED				639
#define IMG_STEEL_EXIT_OPENING				640
#define IMG_STEEL_EXIT_OPEN				641
#define IMG_STEEL_EXIT_CLOSING				642
#define IMG_EM_EXIT_CLOSED				643
#define IMG_EM_EXIT_OPENING				644
#define IMG_EM_EXIT_OPEN				645
#define IMG_EM_EXIT_CLOSING				646
#define IMG_EM_STEEL_EXIT_CLOSED			647
#define IMG_EM_STEEL_EXIT_OPENING			648
#define IMG_EM_STEEL_EXIT_OPEN				649
#define IMG_EM_STEEL_EXIT_CLOSING			650
#define IMG_BALLOON					651
#define IMG_BALLOON_MOVING				652
#define IMG_BALLOON_PUSHING				653
#define IMG_BALLOON_SWITCH_LEFT				654
#define IMG_BALLOON_SWITCH_RIGHT			655
#define IMG_BALLOON_SWITCH_UP				656
#define IMG_BALLOON_SWITCH_DOWN				657
#define IMG_BALLOON_SWITCH_ANY				658
#define IMG_BALLOON_SWITCH_NONE				659
#define IMG_SPRING					660
#define IMG_SPRING_LEFT					661
#define IMG_SPRING_RIGHT				662
#define IMG_EMC_STEELWALL_1				663
#define IMG_EMC_STEELWALL_2				664
#define IMG_EMC_STEELWALL_3				665
#define IMG_EMC_STEELWALL_4				666
#define IMG_EMC_WALL_1					667
#define IMG_EMC_WALL_2					668
#define IMG_EMC_WALL_3					669
#define IMG_EMC_WALL_4					670
#define IMG_EMC_WALL_5					671
#define IMG_EMC_WALL_6					672
#define IMG_EMC_WALL_7					673
#define IMG_EMC_WALL_8					674
#define IMG_INVISIBLE_STEELWALL				675
#define IMG_INVISIBLE_STEELWALL_EDITOR			676
#define IMG_INVISIBLE_STEELWALL_ACTIVE			677
#define IMG_INVISIBLE_WALL				678
#define IMG_INVISIBLE_WALL_EDITOR			679
#define IMG_INVISIBLE_WALL_ACTIVE			680
#define IMG_INVISIBLE_SAND				681
#define IMG_INVISIBLE_SAND_EDITOR			682
#define IMG_INVISIBLE_SAND_ACTIVE			683
#define IMG_INVISIBLE_SAND_ACTIVE_CRUMBLED		684
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_LEFT		685
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_RIGHT		686
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_UP		687
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_DOWN		688
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_LEFT_CRUMBLED	689
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_RIGHT_CRUMBLED	690
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_UP_CRUMBLED	691
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_DOWN_CRUMBLED	692
#define IMG_CONVEYOR_BELT_1_MIDDLE			693
#define IMG_CONVEYOR_BELT_1_MIDDLE_ACTIVE		694
#define IMG_CONVEYOR_BELT_1_LEFT			695
#define IMG_CONVEYOR_BELT_1_LEFT_ACTIVE			696
#define IMG_CONVEYOR_BELT_1_RIGHT			697
#define IMG_CONVEYOR_BELT_1_RIGHT_ACTIVE		698
#define IMG_CONVEYOR_BELT_1_SWITCH_LEFT			699
#define IMG_CONVEYOR_BELT_1_SWITCH_MIDDLE		700
#define IMG_CONVEYOR_BELT_1_SWITCH_RIGHT		701
#define IMG_CONVEYOR_BELT_2_MIDDLE			702
#define IMG_CONVEYOR_BELT_2_MIDDLE_ACTIVE		703
#define IMG_CONVEYOR_BELT_2_LEFT			704
#define IMG_CONVEYOR_BELT_2_LEFT_ACTIVE			705
#define IMG_CONVEYOR_BELT_2_RIGHT			706
#define IMG_CONVEYOR_BELT_2_RIGHT_ACTIVE		707
#define IMG_CONVEYOR_BELT_2_SWITCH_LEFT			708
#define IMG_CONVEYOR_BELT_2_SWITCH_MIDDLE		709
#define IMG_CONVEYOR_BELT_2_SWITCH_RIGHT		710
#define IMG_CONVEYOR_BELT_3_MIDDLE			711
#define IMG_CONVEYOR_BELT_3_MIDDLE_ACTIVE		712
#define IMG_CONVEYOR_BELT_3_LEFT			713
#define IMG_CONVEYOR_BELT_3_LEFT_ACTIVE			714
#define IMG_CONVEYOR_BELT_3_RIGHT			715
#define IMG_CONVEYOR_BELT_3_RIGHT_ACTIVE		716
#define IMG_CONVEYOR_BELT_3_SWITCH_LEFT			717
#define IMG_CONVEYOR_BELT_3_SWITCH_MIDDLE		718
#define IMG_CONVEYOR_BELT_3_SWITCH_RIGHT		719
#define IMG_CONVEYOR_BELT_4_MIDDLE			720
#define IMG_CONVEYOR_BELT_4_MIDDLE_ACTIVE		721
#define IMG_CONVEYOR_BELT_4_LEFT			722
#define IMG_CONVEYOR_BELT_4_LEFT_ACTIVE			723
#define IMG_CONVEYOR_BELT_4_RIGHT			724
#define IMG_CONVEYOR_BELT_4_RIGHT_ACTIVE		725
#define IMG_CONVEYOR_BELT_4_SWITCH_LEFT			726
#define IMG_CONVEYOR_BELT_4_SWITCH_MIDDLE		727
#define IMG_CONVEYOR_BELT_4_SWITCH_RIGHT		728
#define IMG_SWITCHGATE_SWITCH_UP			729
#define IMG_SWITCHGATE_SWITCH_DOWN			730
#define IMG_DC_SWITCHGATE_SWITCH_UP			731
#define IMG_DC_SWITCHGATE_SWITCH_DOWN			732
#define IMG_LIGHT_SWITCH				733
#define IMG_LIGHT_SWITCH_ACTIVE				734
#define IMG_TIMEGATE_SWITCH				735
#define IMG_TIMEGATE_SWITCH_ACTIVE			736
#define IMG_DC_TIMEGATE_SWITCH				737
#define IMG_DC_TIMEGATE_SWITCH_ACTIVE			738
#define IMG_ENVELOPE_1					739
#define IMG_ENVELOPE_1_COLLECTING			740
#define IMG_ENVELOPE_2					741
#define IMG_ENVELOPE_2_COLLECTING			742
#define IMG_ENVELOPE_3					743
#define IMG_ENVELOPE_3_COLLECTING			744
#define IMG_ENVELOPE_4					745
#define IMG_ENVELOPE_4_COLLECTING			746
#define IMG_SIGN_RADIOACTIVITY				747
#define IMG_SIGN_GIVE_WAY				748
#define IMG_SIGN_NO_ENTRY				749
#define IMG_SIGN_EMERGENCY_EXIT				750
#define IMG_SIGN_YIN_YANG				751
#define IMG_SIGN_EXCLAMATION				752
#define IMG_SIGN_STOP					753
#define IMG_SIGN_PARKING				754
#define IMG_SIGN_WHEELCHAIR				755
#define IMG_SIGN_ENTRY_FORBIDDEN			756
#define IMG_SPERMS					757
#define IMG_BULLET					758
#define IMG_HEART					759
#define IMG_CROSS					760
#define IMG_FRANKIE					761
#define IMG_SIGN_SPERMS					762
#define IMG_SIGN_BULLET					763
#define IMG_SIGN_HEART					764
#define IMG_SIGN_CROSS					765
#define IMG_SIGN_FRANKIE				766
#define IMG_LANDMINE					767
#define IMG_DC_LANDMINE					768
#define IMG_STEELWALL_SLIPPERY				769
#define IMG_EXTRA_TIME					770
#define IMG_EXTRA_TIME_COLLECTING			771
#define IMG_SHIELD_NORMAL				772
#define IMG_SHIELD_NORMAL_ACTIVE			773
#define IMG_SHIELD_NORMAL_COLLECTING			774
#define IMG_SHIELD_DEADLY				775
#define IMG_SHIELD_DEADLY_ACTIVE			776
#define IMG_SHIELD_DEADLY_COLLECTING			777
#define IMG_SWITCHGATE_CLOSED				778
#define IMG_SWITCHGATE_OPENING				779
#define IMG_SWITCHGATE_OPEN				780
#define IMG_SWITCHGATE_CLOSING				781
#define IMG_TIMEGATE_CLOSED				782
#define IMG_TIMEGATE_OPENING				783
#define IMG_TIMEGATE_OPEN				784
#define IMG_TIMEGATE_CLOSING				785
#define IMG_PEARL					786
#define IMG_PEARL_BREAKING				787
#define IMG_PEARL_COLLECTING				788
#define IMG_CRYSTAL					789
#define IMG_CRYSTAL_COLLECTING				790
#define IMG_WALL_PEARL					791
#define IMG_WALL_CRYSTAL				792
#define IMG_DC_STEELWALL_1_LEFT				793
#define IMG_DC_STEELWALL_1_RIGHT			794
#define IMG_DC_STEELWALL_1_TOP				795
#define IMG_DC_STEELWALL_1_BOTTOM			796
#define IMG_DC_STEELWALL_1_HORIZONTAL			797
#define IMG_DC_STEELWALL_1_VERTICAL			798
#define IMG_DC_STEELWALL_1_TOPLEFT			799
#define IMG_DC_STEELWALL_1_TOPRIGHT			800
#define IMG_DC_STEELWALL_1_BOTTOMLEFT			801
#define IMG_DC_STEELWALL_1_BOTTOMRIGHT			802
#define IMG_DC_STEELWALL_1_TOPLEFT_2			803
#define IMG_DC_STEELWALL_1_TOPRIGHT_2			804
#define IMG_DC_STEELWALL_1_BOTTOMLEFT_2			805
#define IMG_DC_STEELWALL_1_BOTTOMRIGHT_2		806
#define IMG_DC_STEELWALL_2_LEFT				807
#define IMG_DC_STEELWALL_2_RIGHT			808
#define IMG_DC_STEELWALL_2_TOP				809
#define IMG_DC_STEELWALL_2_BOTTOM			810
#define IMG_DC_STEELWALL_2_HORIZONTAL			811
#define IMG_DC_STEELWALL_2_VERTICAL			812
#define IMG_DC_STEELWALL_2_MIDDLE			813
#define IMG_DC_STEELWALL_2_SINGLE			814
#define IMG_TUBE_RIGHT_DOWN				815
#define IMG_TUBE_HORIZONTAL_DOWN			816
#define IMG_TUBE_LEFT_DOWN				817
#define IMG_TUBE_HORIZONTAL				818
#define IMG_TUBE_VERTICAL_RIGHT				819
#define IMG_TUBE_ANY					820
#define IMG_TUBE_VERTICAL_LEFT				821
#define IMG_TUBE_VERTICAL				822
#define IMG_TUBE_RIGHT_UP				823
#define IMG_TUBE_HORIZONTAL_UP				824
#define IMG_TUBE_LEFT_UP				825
#define IMG_TRAP					826
#define IMG_TRAP_ACTIVE					827
#define IMG_DX_SUPABOMB					828
#define IMG_KEY_1					829
#define IMG_KEY_1_COLLECTING				830
#define IMG_KEY_2					831
#define IMG_KEY_2_COLLECTING				832
#define IMG_KEY_3					833
#define IMG_KEY_3_COLLECTING				834
#define IMG_KEY_4					835
#define IMG_KEY_4_COLLECTING				836
#define IMG_GATE_1					837
#define IMG_GATE_2					838
#define IMG_GATE_3					839
#define IMG_GATE_4					840
#define IMG_GATE_1_GRAY					841
#define IMG_GATE_1_GRAY_EDITOR				842
#define IMG_GATE_1_GRAY_ACTIVE				843
#define IMG_GATE_2_GRAY					844
#define IMG_GATE_2_GRAY_EDITOR				845
#define IMG_GATE_2_GRAY_ACTIVE				846
#define IMG_GATE_3_GRAY					847
#define IMG_GATE_3_GRAY_EDITOR				848
#define IMG_GATE_3_GRAY_ACTIVE				849
#define IMG_GATE_4_GRAY					850
#define IMG_GATE_4_GRAY_EDITOR				851
#define IMG_GATE_4_GRAY_ACTIVE				852
#define IMG_GAME_OF_LIFE				853
#define IMG_BIOMAZE					854
#define IMG_PACMAN					855
#define IMG_PACMAN_RIGHT				856
#define IMG_PACMAN_UP					857
#define IMG_PACMAN_LEFT					858
#define IMG_PACMAN_DOWN					859
#define IMG_PACMAN_TURNING_FROM_RIGHT			860
#define IMG_PACMAN_TURNING_FROM_UP			861
#define IMG_PACMAN_TURNING_FROM_LEFT			862
#define IMG_PACMAN_TURNING_FROM_DOWN			863
#define IMG_LAMP					864
#define IMG_LAMP_ACTIVE					865
#define IMG_TIME_ORB_FULL				866
#define IMG_TIME_ORB_EMPTY				867
#define IMG_EMERALD_YELLOW				868
#define IMG_EMERALD_YELLOW_MOVING			869
#define IMG_EMERALD_YELLOW_FALLING			870
#define IMG_EMERALD_YELLOW_COLLECTING			871
#define IMG_EMERALD_RED					872
#define IMG_EMERALD_RED_MOVING				873
#define IMG_EMERALD_RED_FALLING				874
#define IMG_EMERALD_RED_COLLECTING			875
#define IMG_EMERALD_PURPLE				876
#define IMG_EMERALD_PURPLE_MOVING			877
#define IMG_EMERALD_PURPLE_FALLING			878
#define IMG_EMERALD_PURPLE_COLLECTING			879
#define IMG_WALL_EMERALD_YELLOW				880
#define IMG_WALL_EMERALD_RED				881
#define IMG_WALL_EMERALD_PURPLE				882
#define IMG_WALL_BD_DIAMOND				883
#define IMG_EXPANDABLE_WALL				884
#define IMG_EXPANDABLE_WALL_HORIZONTAL			885
#define IMG_EXPANDABLE_WALL_HORIZONTAL_EDITOR		886
#define IMG_EXPANDABLE_WALL_VERTICAL			887
#define IMG_EXPANDABLE_WALL_VERTICAL_EDITOR		888
#define IMG_EXPANDABLE_WALL_ANY				889
#define IMG_EXPANDABLE_WALL_ANY_EDITOR			890
#define IMG_EXPANDABLE_STEELWALL_HORIZONTAL		891
#define IMG_EXPANDABLE_STEELWALL_HORIZONTAL_EDITOR	892
#define IMG_EXPANDABLE_STEELWALL_VERTICAL		893
#define IMG_EXPANDABLE_STEELWALL_VERTICAL_EDITOR	894
#define IMG_EXPANDABLE_STEELWALL_ANY			895
#define IMG_EXPANDABLE_STEELWALL_ANY_EDITOR		896
#define IMG_EXPANDABLE_WALL_GROWING_LEFT		897
#define IMG_EXPANDABLE_WALL_GROWING_RIGHT		898
#define IMG_EXPANDABLE_WALL_GROWING_UP			899
#define IMG_EXPANDABLE_WALL_GROWING_DOWN		900
#define IMG_EXPANDABLE_STEELWALL_GROWING_LEFT		901
#define IMG_EXPANDABLE_STEELWALL_GROWING_RIGHT		902
#define IMG_EXPANDABLE_STEELWALL_GROWING_UP		903
#define IMG_EXPANDABLE_STEELWALL_GROWING_DOWN		904
#define IMG_BLACK_ORB					905
#define IMG_SPEED_PILL					906
#define IMG_SPEED_PILL_COLLECTING			907
#define IMG_DARK_YAMYAM					908
#define IMG_DYNABOMB					909
#define IMG_DYNABOMB_ACTIVE				910
#define IMG_DYNABOMB_PLAYER_1				911
#define IMG_DYNABOMB_PLAYER_1_ACTIVE			912
#define IMG_DYNABOMB_PLAYER_2				913
#define IMG_DYNABOMB_PLAYER_2_ACTIVE			914
#define IMG_DYNABOMB_PLAYER_3				915
#define IMG_DYNABOMB_PLAYER_3_ACTIVE			916
#define IMG_DYNABOMB_PLAYER_4				917
#define IMG_DYNABOMB_PLAYER_4_ACTIVE			918
#define IMG_DYNABOMB_INCREASE_NUMBER			919
#define IMG_DYNABOMB_INCREASE_NUMBER_COLLECTING		920
#define IMG_DYNABOMB_INCREASE_SIZE			921
#define IMG_DYNABOMB_INCREASE_SIZE_COLLECTING		922
#define IMG_DYNABOMB_INCREASE_POWER			923
#define IMG_DYNABOMB_INCREASE_POWER_COLLECTING		924
#define IMG_PIG						925
#define IMG_PIG_DOWN					926
#define IMG_PIG_UP					927
#define IMG_PIG_LEFT					928
#define IMG_PIG_RIGHT					929
#define IMG_PIG_MOVING_DOWN				930
#define IMG_PIG_MOVING_UP				931
#define IMG_PIG_MOVING_LEFT				932
#define IMG_PIG_MOVING_RIGHT				933
#define IMG_PIG_DIGGING_DOWN				934
#define IMG_PIG_DIGGING_UP				935
#define IMG_PIG_DIGGING_LEFT				936
#define IMG_PIG_DIGGING_RIGHT				937
#define IMG_DRAGON					938
#define IMG_DRAGON_DOWN					939
#define IMG_DRAGON_UP					940
#define IMG_DRAGON_LEFT					941
#define IMG_DRAGON_RIGHT				942
#define IMG_DRAGON_MOVING_DOWN				943
#define IMG_DRAGON_MOVING_UP				944
#define IMG_DRAGON_MOVING_LEFT				945
#define IMG_DRAGON_MOVING_RIGHT				946
#define IMG_DRAGON_ATTACKING_DOWN			947
#define IMG_DRAGON_ATTACKING_UP				948
#define IMG_DRAGON_ATTACKING_LEFT			949
#define IMG_DRAGON_ATTACKING_RIGHT			950
#define IMG_MOLE					951
#define IMG_MOLE_DOWN					952
#define IMG_MOLE_UP					953
#define IMG_MOLE_LEFT					954
#define IMG_MOLE_RIGHT					955
#define IMG_MOLE_MOVING_DOWN				956
#define IMG_MOLE_MOVING_UP				957
#define IMG_MOLE_MOVING_LEFT				958
#define IMG_MOLE_MOVING_RIGHT				959
#define IMG_MOLE_DIGGING_DOWN				960
#define IMG_MOLE_DIGGING_UP				961
#define IMG_MOLE_DIGGING_LEFT				962
#define IMG_MOLE_DIGGING_RIGHT				963
#define IMG_PENGUIN					964
#define IMG_PENGUIN_DOWN				965
#define IMG_PENGUIN_UP					966
#define IMG_PENGUIN_LEFT				967
#define IMG_PENGUIN_RIGHT				968
#define IMG_PENGUIN_MOVING_DOWN				969
#define IMG_PENGUIN_MOVING_UP				970
#define IMG_PENGUIN_MOVING_LEFT				971
#define IMG_PENGUIN_MOVING_RIGHT			972
#define IMG_SATELLITE					973
#define IMG_FLAMES_1_LEFT				974
#define IMG_FLAMES_2_LEFT				975
#define IMG_FLAMES_3_LEFT				976
#define IMG_FLAMES_1_RIGHT				977
#define IMG_FLAMES_2_RIGHT				978
#define IMG_FLAMES_3_RIGHT				979
#define IMG_FLAMES_1_UP					980
#define IMG_FLAMES_2_UP					981
#define IMG_FLAMES_3_UP					982
#define IMG_FLAMES_1_DOWN				983
#define IMG_FLAMES_2_DOWN				984
#define IMG_FLAMES_3_DOWN				985
#define IMG_STONEBLOCK					986
#define IMG_PLAYER_1					987
#define IMG_PLAYER_1_DOWN				988
#define IMG_PLAYER_1_UP					989
#define IMG_PLAYER_1_LEFT				990
#define IMG_PLAYER_1_RIGHT				991
#define IMG_PLAYER_1_MOVING_DOWN			992
#define IMG_PLAYER_1_MOVING_UP				993
#define IMG_PLAYER_1_MOVING_LEFT			994
#define IMG_PLAYER_1_MOVING_RIGHT			995
#define IMG_PLAYER_1_DIGGING_DOWN			996
#define IMG_PLAYER_1_DIGGING_UP				997
#define IMG_PLAYER_1_DIGGING_LEFT			998
#define IMG_PLAYER_1_DIGGING_RIGHT			999
#define IMG_PLAYER_1_COLLECTING_DOWN			1000
#define IMG_PLAYER_1_COLLECTING_UP			1001
#define IMG_PLAYER_1_COLLECTING_LEFT			1002
#define IMG_PLAYER_1_COLLECTING_RIGHT			1003
#define IMG_PLAYER_1_PUSHING_DOWN			1004
#define IMG_PLAYER_1_PUSHING_UP				1005
#define IMG_PLAYER_1_PUSHING_LEFT			1006
#define IMG_PLAYER_1_PUSHING_RIGHT			1007
#define IMG_PLAYER_1_SNAPPING_DOWN			1008
#define IMG_PLAYER_1_SNAPPING_UP			1009
#define IMG_PLAYER_1_SNAPPING_LEFT			1010
#define IMG_PLAYER_1_SNAPPING_RIGHT			1011
#define IMG_PLAYER_2					1012
#define IMG_PLAYER_2_DOWN				1013
#define IMG_PLAYER_2_UP					1014
#define IMG_PLAYER_2_LEFT				1015
#define IMG_PLAYER_2_RIGHT				1016
#define IMG_PLAYER_2_MOVING_DOWN			1017
#define IMG_PLAYER_2_MOVING_UP				1018
#define IMG_PLAYER_2_MOVING_LEFT			1019
#define IMG_PLAYER_2_MOVING_RIGHT			1020
#define IMG_PLAYER_2_DIGGING_DOWN			1021
#define IMG_PLAYER_2_DIGGING_UP				1022
#define IMG_PLAYER_2_DIGGING_LEFT			1023
#define IMG_PLAYER_2_DIGGING_RIGHT			1024
#define IMG_PLAYER_2_COLLECTING_DOWN			1025
#define IMG_PLAYER_2_COLLECTING_UP			1026
#define IMG_PLAYER_2_COLLECTING_LEFT			1027
#define IMG_PLAYER_2_COLLECTING_RIGHT			1028
#define IMG_PLAYER_2_PUSHING_DOWN			1029
#define IMG_PLAYER_2_PUSHING_UP				1030
#define IMG_PLAYER_2_PUSHING_LEFT			1031
#define IMG_PLAYER_2_PUSHING_RIGHT			1032
#define IMG_PLAYER_2_SNAPPING_DOWN			1033
#define IMG_PLAYER_2_SNAPPING_UP			1034
#define IMG_PLAYER_2_SNAPPING_LEFT			1035
#define IMG_PLAYER_2_SNAPPING_RIGHT			1036
#define IMG_PLAYER_3					1037
#define IMG_PLAYER_3_DOWN				1038
#define IMG_PLAYER_3_UP					1039
#define IMG_PLAYER_3_LEFT				1040
#define IMG_PLAYER_3_RIGHT				1041
#define IMG_PLAYER_3_MOVING_DOWN			1042
#define IMG_PLAYER_3_MOVING_UP				1043
#define IMG_PLAYER_3_MOVING_LEFT			1044
#define IMG_PLAYER_3_MOVING_RIGHT			1045
#define IMG_PLAYER_3_DIGGING_DOWN			1046
#define IMG_PLAYER_3_DIGGING_UP				1047
#define IMG_PLAYER_3_DIGGING_LEFT			1048
#define IMG_PLAYER_3_DIGGING_RIGHT			1049
#define IMG_PLAYER_3_COLLECTING_DOWN			1050
#define IMG_PLAYER_3_COLLECTING_UP			1051
#define IMG_PLAYER_3_COLLECTING_LEFT			1052
#define IMG_PLAYER_3_COLLECTING_RIGHT			1053
#define IMG_PLAYER_3_PUSHING_DOWN			1054
#define IMG_PLAYER_3_PUSHING_UP				1055
#define IMG_PLAYER_3_PUSHING_LEFT			1056
#define IMG_PLAYER_3_PUSHING_RIGHT			1057
#define IMG_PLAYER_3_SNAPPING_DOWN			1058
#define IMG_PLAYER_3_SNAPPING_UP			1059
#define IMG_PLAYER_3_SNAPPING_LEFT			1060
#define IMG_PLAYER_3_SNAPPING_RIGHT			1061
#define IMG_PLAYER_4					1062
#define IMG_PLAYER_4_DOWN				1063
#define IMG_PLAYER_4_UP					1064
#define IMG_PLAYER_4_LEFT				1065
#define IMG_PLAYER_4_RIGHT				1066
#define IMG_PLAYER_4_MOVING_DOWN			1067
#define IMG_PLAYER_4_MOVING_UP				1068
#define IMG_PLAYER_4_MOVING_LEFT			1069
#define IMG_PLAYER_4_MOVING_RIGHT			1070
#define IMG_PLAYER_4_DIGGING_DOWN			1071
#define IMG_PLAYER_4_DIGGING_UP				1072
#define IMG_PLAYER_4_DIGGING_LEFT			1073
#define IMG_PLAYER_4_DIGGING_RIGHT			1074
#define IMG_PLAYER_4_COLLECTING_DOWN			1075
#define IMG_PLAYER_4_COLLECTING_UP			1076
#define IMG_PLAYER_4_COLLECTING_LEFT			1077
#define IMG_PLAYER_4_COLLECTING_RIGHT			1078
#define IMG_PLAYER_4_PUSHING_DOWN			1079
#define IMG_PLAYER_4_PUSHING_UP				1080
#define IMG_PLAYER_4_PUSHING_LEFT			1081
#define IMG_PLAYER_4_PUSHING_RIGHT			1082
#define IMG_PLAYER_4_SNAPPING_DOWN			1083
#define IMG_PLAYER_4_SNAPPING_UP			1084
#define IMG_PLAYER_4_SNAPPING_LEFT			1085
#define IMG_PLAYER_4_SNAPPING_RIGHT			1086
#define IMG_DEFAULT_EXPLODING				1087
#define IMG_TWINKLE_BLUE				1088
#define IMG_TWINKLE_WHITE				1089
#define IMG_STEELWALL_TOPLEFT				1090
#define IMG_STEELWALL_TOPRIGHT				1091
#define IMG_STEELWALL_BOTTOMLEFT			1092
#define IMG_STEELWALL_BOTTOMRIGHT			1093
#define IMG_STEELWALL_HORIZONTAL			1094
#define IMG_STEELWALL_VERTICAL				1095
#define IMG_STEELWALL_TOPLEFT_EDITOR			1096
#define IMG_STEELWALL_TOPRIGHT_EDITOR			1097
#define IMG_STEELWALL_BOTTOMLEFT_EDITOR			1098
#define IMG_STEELWALL_BOTTOMRIGHT_EDITOR		1099
#define IMG_STEELWALL_HORIZONTAL_EDITOR			1100
#define IMG_STEELWALL_VERTICAL_EDITOR			1101
#define IMG_INVISIBLE_STEELWALL_TOPLEFT			1102
#define IMG_INVISIBLE_STEELWALL_TOPRIGHT		1103
#define IMG_INVISIBLE_STEELWALL_BOTTOMLEFT		1104
#define IMG_INVISIBLE_STEELWALL_BOTTOMRIGHT		1105
#define IMG_INVISIBLE_STEELWALL_HORIZONTAL		1106
#define IMG_INVISIBLE_STEELWALL_VERTICAL		1107
#define IMG_INVISIBLE_STEELWALL_TOPLEFT_EDITOR		1108
#define IMG_INVISIBLE_STEELWALL_TOPRIGHT_EDITOR		1109
#define IMG_INVISIBLE_STEELWALL_BOTTOMLEFT_EDITOR	1110
#define IMG_INVISIBLE_STEELWALL_BOTTOMRIGHT_EDITOR	1111
#define IMG_INVISIBLE_STEELWALL_HORIZONTAL_EDITOR	1112
#define IMG_INVISIBLE_STEELWALL_VERTICAL_EDITOR		1113
#define IMG_ARROW_LEFT					1114
#define IMG_ARROW_RIGHT					1115
#define IMG_ARROW_UP					1116
#define IMG_ARROW_DOWN					1117
#define IMG_UNKNOWN					1118
#define IMG_TRIGGER_ELEMENT				1119
#define IMG_TRIGGER_PLAYER				1120
#define IMG_TRIGGER_CE_VALUE				1121
#define IMG_TRIGGER_CE_SCORE				1122
#define IMG_CURRENT_CE_VALUE				1123
#define IMG_CURRENT_CE_SCORE				1124
#define IMG_PREV_CE_1					1125
#define IMG_PREV_CE_2					1126
#define IMG_PREV_CE_3					1127
#define IMG_PREV_CE_4					1128
#define IMG_PREV_CE_5					1129
#define IMG_PREV_CE_6					1130
#define IMG_PREV_CE_7					1131
#define IMG_PREV_CE_8					1132
#define IMG_NEXT_CE_1					1133
#define IMG_NEXT_CE_2					1134
#define IMG_NEXT_CE_3					1135
#define IMG_NEXT_CE_4					1136
#define IMG_NEXT_CE_5					1137
#define IMG_NEXT_CE_6					1138
#define IMG_NEXT_CE_7					1139
#define IMG_NEXT_CE_8					1140
#define IMG_SELF					1141
#define IMG_ANY_ELEMENT					1142
#define IMG_EMC_KEY_5					1143
#define IMG_EMC_KEY_5_COLLECTING			1144
#define IMG_EMC_KEY_6					1145
#define IMG_EMC_KEY_6_COLLECTING			1146
#define IMG_EMC_KEY_7					1147
#define IMG_EMC_KEY_7_COLLECTING			1148
#define IMG_EMC_KEY_8					1149
#define IMG_EMC_KEY_8_COLLECTING			1150
#define IMG_EMC_GATE_5					1151
#define IMG_EMC_GATE_6					1152
#define IMG_EMC_GATE_7					1153
#define IMG_EMC_GATE_8					1154
#define IMG_EMC_GATE_5_GRAY				1155
#define IMG_EMC_GATE_5_GRAY_EDITOR			1156
#define IMG_EMC_GATE_5_GRAY_ACTIVE			1157
#define IMG_EMC_GATE_6_GRAY				1158
#define IMG_EMC_GATE_6_GRAY_EDITOR			1159
#define IMG_EMC_GATE_6_GRAY_ACTIVE			1160
#define IMG_EMC_GATE_7_GRAY				1161
#define IMG_EMC_GATE_7_GRAY_EDITOR			1162
#define IMG_EMC_GATE_7_GRAY_ACTIVE			1163
#define IMG_EMC_GATE_8_GRAY				1164
#define IMG_EMC_GATE_8_GRAY_EDITOR			1165
#define IMG_EMC_GATE_8_GRAY_ACTIVE			1166
#define IMG_EMC_ANDROID					1167
#define IMG_EMC_ANDROID_SHRINKING_UPLEFT		1168
#define IMG_EMC_ANDROID_GROWING_DOWNRIGHT		1169
#define IMG_EMC_ANDROID_SHRINKING_DOWNLEFT		1170
#define IMG_EMC_ANDROID_GROWING_UPRIGHT			1171
#define IMG_EMC_ANDROID_SHRINKING_UPRIGHT		1172
#define IMG_EMC_ANDROID_GROWING_DOWNLEFT		1173
#define IMG_EMC_ANDROID_SHRINKING_DOWNRIGHT		1174
#define IMG_EMC_ANDROID_GROWING_UPLEFT			1175
#define IMG_EMC_GRASS					1176
#define IMG_EMC_GRASS_CRUMBLED				1177
#define IMG_EMC_GRASS_DIGGING_LEFT			1178
#define IMG_EMC_GRASS_DIGGING_RIGHT			1179
#define IMG_EMC_GRASS_DIGGING_UP			1180
#define IMG_EMC_GRASS_DIGGING_DOWN			1181
#define IMG_EMC_GRASS_DIGGING_LEFT_CRUMBLED		1182
#define IMG_EMC_GRASS_DIGGING_RIGHT_CRUMBLED		1183
#define IMG_EMC_GRASS_DIGGING_UP_CRUMBLED		1184
#define IMG_EMC_GRASS_DIGGING_DOWN_CRUMBLED		1185
#define IMG_EMC_MAGIC_BALL				1186
#define IMG_EMC_MAGIC_BALL_ACTIVE			1187
#define IMG_EMC_MAGIC_BALL_DROPPING			1188
#define IMG_EMC_MAGIC_BALL_SWITCH			1189
#define IMG_EMC_MAGIC_BALL_SWITCH_ACTIVE		1190
#define IMG_EMC_SPRING_BUMPER				1191
#define IMG_EMC_SPRING_BUMPER_ACTIVE			1192
#define IMG_EMC_PLANT					1193
#define IMG_EMC_PLANT_CRUMBLED				1194
#define IMG_EMC_LENSES					1195
#define IMG_EMC_LENSES_COLLECTING			1196
#define IMG_EMC_MAGNIFIER				1197
#define IMG_EMC_MAGNIFIER_COLLECTING			1198
#define IMG_EMC_WALL_9					1199
#define IMG_EMC_WALL_10					1200
#define IMG_EMC_WALL_11					1201
#define IMG_EMC_WALL_12					1202
#define IMG_EMC_WALL_13					1203
#define IMG_EMC_WALL_14					1204
#define IMG_EMC_WALL_15					1205
#define IMG_EMC_WALL_16					1206
#define IMG_EMC_WALL_SLIPPERY_1				1207
#define IMG_EMC_WALL_SLIPPERY_2				1208
#define IMG_EMC_WALL_SLIPPERY_3				1209
#define IMG_EMC_WALL_SLIPPERY_4				1210
#define IMG_EMC_FAKE_GRASS				1211
#define IMG_EMC_FAKE_GRASS_CRUMBLED			1212
#define IMG_EMC_FAKE_GRASS_ACTIVE			1213
#define IMG_EMC_FAKE_GRASS_ACTIVE_CRUMBLED		1214
#define IMG_EMC_FAKE_GRASS_EDITOR			1215
#define IMG_EMC_FAKE_ACID				1216
#define IMG_EMC_DRIPPER					1217
#define IMG_EMC_DRIPPER_EDITOR				1218
#define IMG_EMC_DRIPPER_ACTIVE				1219
#define IMG_MM_EMPTY_SPACE				1220
#define IMG_MM_MCDUFFIN					1221
#define IMG_MM_MCDUFFIN_RIGHT				1222
#define IMG_MM_MCDUFFIN_UP				1223
#define IMG_MM_MCDUFFIN_LEFT				1224
#define IMG_MM_MCDUFFIN_DOWN				1225
#define IMG_MM_EXIT_CLOSED				1226
#define IMG_MM_EXIT_OPENING				1227
#define IMG_MM_EXIT_OPEN				1228
#define IMG_MM_EXIT_CLOSING				1229
#define IMG_MM_MIRROR_1					1230
#define IMG_MM_MIRROR_2					1231
#define IMG_MM_MIRROR_3					1232
#define IMG_MM_MIRROR_4					1233
#define IMG_MM_MIRROR_5					1234
#define IMG_MM_MIRROR_6					1235
#define IMG_MM_MIRROR_7					1236
#define IMG_MM_MIRROR_8					1237
#define IMG_MM_MIRROR_9					1238
#define IMG_MM_MIRROR_10				1239
#define IMG_MM_MIRROR_11				1240
#define IMG_MM_MIRROR_12				1241
#define IMG_MM_MIRROR_13				1242
#define IMG_MM_MIRROR_14				1243
#define IMG_MM_MIRROR_15				1244
#define IMG_MM_MIRROR_16				1245
#define IMG_MM_MIRROR_FIXED_1				1246
#define IMG_MM_MIRROR_FIXED_2				1247
#define IMG_MM_MIRROR_FIXED_3				1248
#define IMG_MM_MIRROR_FIXED_4				1249
#define IMG_MM_STEEL_GRID_FIXED_1			1250
#define IMG_MM_STEEL_GRID_FIXED_2			1251
#define IMG_MM_STEEL_GRID_FIXED_3			1252
#define IMG_MM_STEEL_GRID_FIXED_4			1253
#define IMG_MM_WOODEN_GRID_FIXED_1			1254
#define IMG_MM_WOODEN_GRID_FIXED_2			1255
#define IMG_MM_WOODEN_GRID_FIXED_3			1256
#define IMG_MM_WOODEN_GRID_FIXED_4			1257
#define IMG_MM_POLARIZER_1				1258
#define IMG_MM_POLARIZER_2				1259
#define IMG_MM_POLARIZER_3				1260
#define IMG_MM_POLARIZER_4				1261
#define IMG_MM_POLARIZER_5				1262
#define IMG_MM_POLARIZER_6				1263
#define IMG_MM_POLARIZER_7				1264
#define IMG_MM_POLARIZER_8				1265
#define IMG_MM_POLARIZER_9				1266
#define IMG_MM_POLARIZER_10				1267
#define IMG_MM_POLARIZER_11				1268
#define IMG_MM_POLARIZER_12				1269
#define IMG_MM_POLARIZER_13				1270
#define IMG_MM_POLARIZER_14				1271
#define IMG_MM_POLARIZER_15				1272
#define IMG_MM_POLARIZER_16				1273
#define IMG_MM_POLARIZER_CROSS_1			1274
#define IMG_MM_POLARIZER_CROSS_2			1275
#define IMG_MM_POLARIZER_CROSS_3			1276
#define IMG_MM_POLARIZER_CROSS_4			1277
#define IMG_MM_TELEPORTER_1				1278
#define IMG_MM_TELEPORTER_2				1279
#define IMG_MM_TELEPORTER_3				1280
#define IMG_MM_TELEPORTER_4				1281
#define IMG_MM_TELEPORTER_5				1282
#define IMG_MM_TELEPORTER_6				1283
#define IMG_MM_TELEPORTER_7				1284
#define IMG_MM_TELEPORTER_8				1285
#define IMG_MM_TELEPORTER_9				1286
#define IMG_MM_TELEPORTER_10				1287
#define IMG_MM_TELEPORTER_11				1288
#define IMG_MM_TELEPORTER_12				1289
#define IMG_MM_TELEPORTER_13				1290
#define IMG_MM_TELEPORTER_14				1291
#define IMG_MM_TELEPORTER_15				1292
#define IMG_MM_TELEPORTER_16				1293
#define IMG_MM_TELEPORTER_RED_1				1294
#define IMG_MM_TELEPORTER_RED_2				1295
#define IMG_MM_TELEPORTER_RED_3				1296
#define IMG_MM_TELEPORTER_RED_4				1297
#define IMG_MM_TELEPORTER_RED_5				1298
#define IMG_MM_TELEPORTER_RED_6				1299
#define IMG_MM_TELEPORTER_RED_7				1300
#define IMG_MM_TELEPORTER_RED_8				1301
#define IMG_MM_TELEPORTER_RED_9				1302
#define IMG_MM_TELEPORTER_RED_10			1303
#define IMG_MM_TELEPORTER_RED_11			1304
#define IMG_MM_TELEPORTER_RED_12			1305
#define IMG_MM_TELEPORTER_RED_13			1306
#define IMG_MM_TELEPORTER_RED_14			1307
#define IMG_MM_TELEPORTER_RED_15			1308
#define IMG_MM_TELEPORTER_RED_16			1309
#define IMG_MM_TELEPORTER_YELLOW_1			1310
#define IMG_MM_TELEPORTER_YELLOW_2			1311
#define IMG_MM_TELEPORTER_YELLOW_3			1312
#define IMG_MM_TELEPORTER_YELLOW_4			1313
#define IMG_MM_TELEPORTER_YELLOW_5			1314
#define IMG_MM_TELEPORTER_YELLOW_6			1315
#define IMG_MM_TELEPORTER_YELLOW_7			1316
#define IMG_MM_TELEPORTER_YELLOW_8			1317
#define IMG_MM_TELEPORTER_YELLOW_9			1318
#define IMG_MM_TELEPORTER_YELLOW_10			1319
#define IMG_MM_TELEPORTER_YELLOW_11			1320
#define IMG_MM_TELEPORTER_YELLOW_12			1321
#define IMG_MM_TELEPORTER_YELLOW_13			1322
#define IMG_MM_TELEPORTER_YELLOW_14			1323
#define IMG_MM_TELEPORTER_YELLOW_15			1324
#define IMG_MM_TELEPORTER_YELLOW_16			1325
#define IMG_MM_TELEPORTER_GREEN_1			1326
#define IMG_MM_TELEPORTER_GREEN_2			1327
#define IMG_MM_TELEPORTER_GREEN_3			1328
#define IMG_MM_TELEPORTER_GREEN_4			1329
#define IMG_MM_TELEPORTER_GREEN_5			1330
#define IMG_MM_TELEPORTER_GREEN_6			1331
#define IMG_MM_TELEPORTER_GREEN_7			1332
#define IMG_MM_TELEPORTER_GREEN_8			1333
#define IMG_MM_TELEPORTER_GREEN_9			1334
#define IMG_MM_TELEPORTER_GREEN_10			1335
#define IMG_MM_TELEPORTER_GREEN_11			1336
#define IMG_MM_TELEPORTER_GREEN_12			1337
#define IMG_MM_TELEPORTER_GREEN_13			1338
#define IMG_MM_TELEPORTER_GREEN_14			1339
#define IMG_MM_TELEPORTER_GREEN_15			1340
#define IMG_MM_TELEPORTER_GREEN_16			1341
#define IMG_MM_TELEPORTER_BLUE_1			1342
#define IMG_MM_TELEPORTER_BLUE_2			1343
#define IMG_MM_TELEPORTER_BLUE_3			1344
#define IMG_MM_TELEPORTER_BLUE_4			1345
#define IMG_MM_TELEPORTER_BLUE_5			1346
#define IMG_MM_TELEPORTER_BLUE_6			1347
#define IMG_MM_TELEPORTER_BLUE_7			1348
#define IMG_MM_TELEPORTER_BLUE_8			1349
#define IMG_MM_TELEPORTER_BLUE_9			1350
#define IMG_MM_TELEPORTER_BLUE_10			1351
#define IMG_MM_TELEPORTER_BLUE_11			1352
#define IMG_MM_TELEPORTER_BLUE_12			1353
#define IMG_MM_TELEPORTER_BLUE_13			1354
#define IMG_MM_TELEPORTER_BLUE_14			1355
#define IMG_MM_TELEPORTER_BLUE_15			1356
#define IMG_MM_TELEPORTER_BLUE_16			1357
#define IMG_MM_KETTLE					1358
#define IMG_MM_KETTLE_EXPLODING				1359
#define IMG_MM_BOMB					1360
#define IMG_MM_BOMB_ACTIVE				1361
#define IMG_MM_PRISM					1362
#define IMG_MM_FUSE					1363
#define IMG_MM_FUSE_ACTIVE				1364
#define IMG_MM_STEEL_LOCK				1365
#define IMG_MM_STEEL_LOCK_EXPLODING			1366
#define IMG_MM_WOODEN_LOCK				1367
#define IMG_MM_WOODEN_LOCK_EXPLODING			1368
#define IMG_MM_STEEL_BLOCK				1369
#define IMG_MM_WOODEN_BLOCK				1370
#define IMG_MM_KEY					1371
#define IMG_MM_LIGHTBULB				1372
#define IMG_MM_LIGHTBULB_ACTIVE				1373
#define IMG_MM_LIGHTBALL				1374
#define IMG_MM_LIGHTBALL_RED				1375
#define IMG_MM_LIGHTBALL_BLUE				1376
#define IMG_MM_LIGHTBALL_YELLOW				1377
#define IMG_MM_GRAY_BALL				1378
#define IMG_MM_GRAY_BALL_ACTIVE				1379
#define IMG_MM_GRAY_BALL_EDITOR				1380
#define IMG_MM_FUEL_FULL				1381
#define IMG_MM_FUEL_EMPTY				1382
#define IMG_MM_STEEL_WALL				1383
#define IMG_MM_WOODEN_WALL				1384
#define IMG_MM_ICE_WALL					1385
#define IMG_MM_ICE_WALL_SHRINKING			1386
#define IMG_MM_AMOEBA_WALL				1387
#define IMG_MM_AMOEBA_WALL_GROWING			1388
#define IMG_MM_PACMAN					1389
#define IMG_MM_PACMAN_RIGHT				1390
#define IMG_MM_PACMAN_UP				1391
#define IMG_MM_PACMAN_LEFT				1392
#define IMG_MM_PACMAN_DOWN				1393
#define IMG_MM_PACMAN_EATING_RIGHT			1394
#define IMG_MM_PACMAN_EATING_UP				1395
#define IMG_MM_PACMAN_EATING_LEFT			1396
#define IMG_MM_PACMAN_EATING_DOWN			1397
#define IMG_MM_ENVELOPE_1				1398
#define IMG_MM_ENVELOPE_1_COLLECTING			1399
#define IMG_MM_ENVELOPE_2				1400
#define IMG_MM_ENVELOPE_2_COLLECTING			1401
#define IMG_MM_ENVELOPE_3				1402
#define IMG_MM_ENVELOPE_3_COLLECTING			1403
#define IMG_MM_ENVELOPE_4				1404
#define IMG_MM_ENVELOPE_4_COLLECTING			1405
#define IMG_MM_DEFAULT_EXPLODING			1406
#define IMG_DF_EMPTY_SPACE				1407
#define IMG_DF_LASER					1408
#define IMG_DF_LASER_RIGHT				1409
#define IMG_DF_LASER_UP					1410
#define IMG_DF_LASER_LEFT				1411
#define IMG_DF_LASER_DOWN				1412
#define IMG_DF_RECEIVER					1413
#define IMG_DF_RECEIVER_RIGHT				1414
#define IMG_DF_RECEIVER_UP				1415
#define IMG_DF_RECEIVER_LEFT				1416
#define IMG_DF_RECEIVER_DOWN				1417
#define IMG_DF_MIRROR_1					1418
#define IMG_DF_MIRROR_2					1419
#define IMG_DF_MIRROR_3					1420
#define IMG_DF_MIRROR_4					1421
#define IMG_DF_MIRROR_5					1422
#define IMG_DF_MIRROR_6					1423
#define IMG_DF_MIRROR_7					1424
#define IMG_DF_MIRROR_8					1425
#define IMG_DF_MIRROR_9					1426
#define IMG_DF_MIRROR_10				1427
#define IMG_DF_MIRROR_11				1428
#define IMG_DF_MIRROR_12				1429
#define IMG_DF_MIRROR_13				1430
#define IMG_DF_MIRROR_14				1431
#define IMG_DF_MIRROR_15				1432
#define IMG_DF_MIRROR_16				1433
#define IMG_DF_MIRROR_ROTATING_1			1434
#define IMG_DF_MIRROR_ROTATING_1_EDITOR			1435
#define IMG_DF_MIRROR_ROTATING_2			1436
#define IMG_DF_MIRROR_ROTATING_2_EDITOR			1437
#define IMG_DF_MIRROR_ROTATING_3			1438
#define IMG_DF_MIRROR_ROTATING_3_EDITOR			1439
#define IMG_DF_MIRROR_ROTATING_4			1440
#define IMG_DF_MIRROR_ROTATING_4_EDITOR			1441
#define IMG_DF_MIRROR_ROTATING_5			1442
#define IMG_DF_MIRROR_ROTATING_5_EDITOR			1443
#define IMG_DF_MIRROR_ROTATING_6			1444
#define IMG_DF_MIRROR_ROTATING_6_EDITOR			1445
#define IMG_DF_MIRROR_ROTATING_7			1446
#define IMG_DF_MIRROR_ROTATING_7_EDITOR			1447
#define IMG_DF_MIRROR_ROTATING_8			1448
#define IMG_DF_MIRROR_ROTATING_8_EDITOR			1449
#define IMG_DF_MIRROR_ROTATING_9			1450
#define IMG_DF_MIRROR_ROTATING_9_EDITOR			1451
#define IMG_DF_MIRROR_ROTATING_10			1452
#define IMG_DF_MIRROR_ROTATING_10_EDITOR		1453
#define IMG_DF_MIRROR_ROTATING_11			1454
#define IMG_DF_MIRROR_ROTATING_11_EDITOR		1455
#define IMG_DF_MIRROR_ROTATING_12			1456
#define IMG_DF_MIRROR_ROTATING_12_EDITOR		1457
#define IMG_DF_MIRROR_ROTATING_13			1458
#define IMG_DF_MIRROR_ROTATING_13_EDITOR		1459
#define IMG_DF_MIRROR_ROTATING_14			1460
#define IMG_DF_MIRROR_ROTATING_14_EDITOR		1461
#define IMG_DF_MIRROR_ROTATING_15			1462
#define IMG_DF_MIRROR_ROTATING_15_EDITOR		1463
#define IMG_DF_MIRROR_ROTATING_16			1464
#define IMG_DF_MIRROR_ROTATING_16_EDITOR		1465
#define IMG_DF_STEEL_GRID_FIXED_1			1466
#define IMG_DF_STEEL_GRID_FIXED_2			1467
#define IMG_DF_STEEL_GRID_FIXED_3			1468
#define IMG_DF_STEEL_GRID_FIXED_4			1469
#define IMG_DF_STEEL_GRID_FIXED_5			1470
#define IMG_DF_STEEL_GRID_FIXED_6			1471
#define IMG_DF_STEEL_GRID_FIXED_7			1472
#define IMG_DF_STEEL_GRID_FIXED_8			1473
#define IMG_DF_WOODEN_GRID_FIXED_1			1474
#define IMG_DF_WOODEN_GRID_FIXED_2			1475
#define IMG_DF_WOODEN_GRID_FIXED_3			1476
#define IMG_DF_WOODEN_GRID_FIXED_4			1477
#define IMG_DF_WOODEN_GRID_FIXED_5			1478
#define IMG_DF_WOODEN_GRID_FIXED_6			1479
#define IMG_DF_WOODEN_GRID_FIXED_7			1480
#define IMG_DF_WOODEN_GRID_FIXED_8			1481
#define IMG_DF_STEEL_GRID_ROTATING_1			1482
#define IMG_DF_STEEL_GRID_ROTATING_1_EDITOR		1483
#define IMG_DF_STEEL_GRID_ROTATING_2			1484
#define IMG_DF_STEEL_GRID_ROTATING_2_EDITOR		1485
#define IMG_DF_STEEL_GRID_ROTATING_3			1486
#define IMG_DF_STEEL_GRID_ROTATING_3_EDITOR		1487
#define IMG_DF_STEEL_GRID_ROTATING_4			1488
#define IMG_DF_STEEL_GRID_ROTATING_4_EDITOR		1489
#define IMG_DF_STEEL_GRID_ROTATING_5			1490
#define IMG_DF_STEEL_GRID_ROTATING_5_EDITOR		1491
#define IMG_DF_STEEL_GRID_ROTATING_6			1492
#define IMG_DF_STEEL_GRID_ROTATING_6_EDITOR		1493
#define IMG_DF_STEEL_GRID_ROTATING_7			1494
#define IMG_DF_STEEL_GRID_ROTATING_7_EDITOR		1495
#define IMG_DF_STEEL_GRID_ROTATING_8			1496
#define IMG_DF_STEEL_GRID_ROTATING_8_EDITOR		1497
#define IMG_DF_WOODEN_GRID_ROTATING_1			1498
#define IMG_DF_WOODEN_GRID_ROTATING_1_EDITOR		1499
#define IMG_DF_WOODEN_GRID_ROTATING_2			1500
#define IMG_DF_WOODEN_GRID_ROTATING_2_EDITOR		1501
#define IMG_DF_WOODEN_GRID_ROTATING_3			1502
#define IMG_DF_WOODEN_GRID_ROTATING_3_EDITOR		1503
#define IMG_DF_WOODEN_GRID_ROTATING_4			1504
#define IMG_DF_WOODEN_GRID_ROTATING_4_EDITOR		1505
#define IMG_DF_WOODEN_GRID_ROTATING_5			1506
#define IMG_DF_WOODEN_GRID_ROTATING_5_EDITOR		1507
#define IMG_DF_WOODEN_GRID_ROTATING_6			1508
#define IMG_DF_WOODEN_GRID_ROTATING_6_EDITOR		1509
#define IMG_DF_WOODEN_GRID_ROTATING_7			1510
#define IMG_DF_WOODEN_GRID_ROTATING_7_EDITOR		1511
#define IMG_DF_WOODEN_GRID_ROTATING_8			1512
#define IMG_DF_WOODEN_GRID_ROTATING_8_EDITOR		1513
#define IMG_DF_FIBRE_OPTIC_RED_1			1514
#define IMG_DF_FIBRE_OPTIC_RED_1_EDITOR			1515
#define IMG_DF_FIBRE_OPTIC_RED_2			1516
#define IMG_DF_FIBRE_OPTIC_RED_2_EDITOR			1517
#define IMG_DF_FIBRE_OPTIC_YELLOW_1			1518
#define IMG_DF_FIBRE_OPTIC_YELLOW_1_EDITOR		1519
#define IMG_DF_FIBRE_OPTIC_YELLOW_2			1520
#define IMG_DF_FIBRE_OPTIC_YELLOW_2_EDITOR		1521
#define IMG_DF_FIBRE_OPTIC_GREEN_1			1522
#define IMG_DF_FIBRE_OPTIC_GREEN_1_EDITOR		1523
#define IMG_DF_FIBRE_OPTIC_GREEN_2			1524
#define IMG_DF_FIBRE_OPTIC_GREEN_2_EDITOR		1525
#define IMG_DF_FIBRE_OPTIC_BLUE_1			1526
#define IMG_DF_FIBRE_OPTIC_BLUE_1_EDITOR		1527
#define IMG_DF_FIBRE_OPTIC_BLUE_2			1528
#define IMG_DF_FIBRE_OPTIC_BLUE_2_EDITOR		1529
#define IMG_DF_STEEL_WALL				1530
#define IMG_DF_WOODEN_WALL				1531
#define IMG_DF_REFRACTOR				1532
#define IMG_DF_CELL					1533
#define IMG_DF_MINE					1534
#define IMG_DF_MINE_ACTIVE				1535
#define IMG_DF_MIRROR_FIXED_1				1536
#define IMG_DF_MIRROR_FIXED_2				1537
#define IMG_DF_MIRROR_FIXED_3				1538
#define IMG_DF_MIRROR_FIXED_4				1539
#define IMG_DF_MIRROR_FIXED_5				1540
#define IMG_DF_MIRROR_FIXED_6				1541
#define IMG_DF_MIRROR_FIXED_7				1542
#define IMG_DF_MIRROR_FIXED_8				1543
#define IMG_DF_MIRROR_FIXED_9				1544
#define IMG_DF_MIRROR_FIXED_10				1545
#define IMG_DF_MIRROR_FIXED_11				1546
#define IMG_DF_MIRROR_FIXED_12				1547
#define IMG_DF_MIRROR_FIXED_13				1548
#define IMG_DF_MIRROR_FIXED_14				1549
#define IMG_DF_MIRROR_FIXED_15				1550
#define IMG_DF_MIRROR_FIXED_16				1551
#define IMG_DF_SLOPE_1					1552
#define IMG_DF_SLOPE_2					1553
#define IMG_DF_SLOPE_3					1554
#define IMG_DF_SLOPE_4					1555
#define IMG_GRAPHIC_1					1556
#define IMG_GRAPHIC_2					1557
#define IMG_GRAPHIC_3					1558
#define IMG_GRAPHIC_4					1559
#define IMG_GRAPHIC_5					1560
#define IMG_GRAPHIC_6					1561
#define IMG_GRAPHIC_7					1562
#define IMG_GRAPHIC_8					1563
#define IMG_CHAR_SPACE					1564
#define IMG_CHAR_SPACE_EDITOR				1565
#define IMG_CHAR_EXCLAM					1566
#define IMG_CHAR_QUOTEDBL				1567
#define IMG_CHAR_NUMBERSIGN				1568
#define IMG_CHAR_DOLLAR					1569
#define IMG_CHAR_PERCENT				1570
#define IMG_CHAR_AMPERSAND				1571
#define IMG_CHAR_APOSTROPHE				1572
#define IMG_CHAR_PARENLEFT				1573
#define IMG_CHAR_PARENRIGHT				1574
#define IMG_CHAR_ASTERISK				1575
#define IMG_CHAR_PLUS					1576
#define IMG_CHAR_COMMA					1577
#define IMG_CHAR_MINUS					1578
#define IMG_CHAR_PERIOD					1579
#define IMG_CHAR_SLASH					1580
#define IMG_CHAR_0					1581
#define IMG_CHAR_1					1582
#define IMG_CHAR_2					1583
#define IMG_CHAR_3					1584
#define IMG_CHAR_4					1585
#define IMG_CHAR_5					1586
#define IMG_CHAR_6					1587
#define IMG_CHAR_7					1588
#define IMG_CHAR_8					1589
#define IMG_CHAR_9					1590
#define IMG_CHAR_COLON					1591
#define IMG_CHAR_SEMICOLON				1592
#define IMG_CHAR_LESS					1593
#define IMG_CHAR_EQUAL					1594
#define IMG_CHAR_GREATER				1595
#define IMG_CHAR_QUESTION				1596
#define IMG_CHAR_AT					1597
#define IMG_CHAR_A					1598
#define IMG_CHAR_B					1599
#define IMG_CHAR_C					1600
#define IMG_CHAR_D					1601
#define IMG_CHAR_E					1602
#define IMG_CHAR_F					1603
#define IMG_CHAR_G					1604
#define IMG_CHAR_H					1605
#define IMG_CHAR_I					1606
#define IMG_CHAR_J					1607
#define IMG_CHAR_K					1608
#define IMG_CHAR_L					1609
#define IMG_CHAR_M					1610
#define IMG_CHAR_N					1611
#define IMG_CHAR_O					1612
#define IMG_CHAR_P					1613
#define IMG_CHAR_Q					1614
#define IMG_CHAR_R					1615
#define IMG_CHAR_S					1616
#define IMG_CHAR_T					1617
#define IMG_CHAR_U					1618
#define IMG_CHAR_V					1619
#define IMG_CHAR_W					1620
#define IMG_CHAR_X					1621
#define IMG_CHAR_Y					1622
#define IMG_CHAR_Z					1623
#define IMG_CHAR_BRACKETLEFT				1624
#define IMG_CHAR_BACKSLASH				1625
#define IMG_CHAR_BRACKETRIGHT				1626
#define IMG_CHAR_ASCIICIRCUM				1627
#define IMG_CHAR_UNDERSCORE				1628
#define IMG_CHAR_COPYRIGHT				1629
#define IMG_CHAR_AUMLAUT				1630
#define IMG_CHAR_OUMLAUT				1631
#define IMG_CHAR_UUMLAUT				1632
#define IMG_CHAR_DEGREE					1633
#define IMG_CHAR_TRADEMARK				1634
#define IMG_CHAR_CURSOR					1635
#define IMG_CHAR_BUTTON					1636
#define IMG_CHAR_UP					1637
#define IMG_CHAR_DOWN					1638
#define IMG_STEEL_CHAR_SPACE				1639
#define IMG_STEEL_CHAR_SPACE_EDITOR			1640
#define IMG_STEEL_CHAR_EXCLAM				1641
#define IMG_STEEL_CHAR_QUOTEDBL				1642
#define IMG_STEEL_CHAR_NUMBERSIGN			1643
#define IMG_STEEL_CHAR_DOLLAR				1644
#define IMG_STEEL_CHAR_PERCENT				1645
#define IMG_STEEL_CHAR_AMPERSAND			1646
#define IMG_STEEL_CHAR_APOSTROPHE			1647
#define IMG_STEEL_CHAR_PARENLEFT			1648
#define IMG_STEEL_CHAR_PARENRIGHT			1649
#define IMG_STEEL_CHAR_ASTERISK				1650
#define IMG_STEEL_CHAR_PLUS				1651
#define IMG_STEEL_CHAR_COMMA				1652
#define IMG_STEEL_CHAR_MINUS				1653
#define IMG_STEEL_CHAR_PERIOD				1654
#define IMG_STEEL_CHAR_SLASH				1655
#define IMG_STEEL_CHAR_0				1656
#define IMG_STEEL_CHAR_1				1657
#define IMG_STEEL_CHAR_2				1658
#define IMG_STEEL_CHAR_3				1659
#define IMG_STEEL_CHAR_4				1660
#define IMG_STEEL_CHAR_5				1661
#define IMG_STEEL_CHAR_6				1662
#define IMG_STEEL_CHAR_7				1663
#define IMG_STEEL_CHAR_8				1664
#define IMG_STEEL_CHAR_9				1665
#define IMG_STEEL_CHAR_COLON				1666
#define IMG_STEEL_CHAR_SEMICOLON			1667
#define IMG_STEEL_CHAR_LESS				1668
#define IMG_STEEL_CHAR_EQUAL				1669
#define IMG_STEEL_CHAR_GREATER				1670
#define IMG_STEEL_CHAR_QUESTION				1671
#define IMG_STEEL_CHAR_AT				1672
#define IMG_STEEL_CHAR_A				1673
#define IMG_STEEL_CHAR_B				1674
#define IMG_STEEL_CHAR_C				1675
#define IMG_STEEL_CHAR_D				1676
#define IMG_STEEL_CHAR_E				1677
#define IMG_STEEL_CHAR_F				1678
#define IMG_STEEL_CHAR_G				1679
#define IMG_STEEL_CHAR_H				1680
#define IMG_STEEL_CHAR_I				1681
#define IMG_STEEL_CHAR_J				1682
#define IMG_STEEL_CHAR_K				1683
#define IMG_STEEL_CHAR_L				1684
#define IMG_STEEL_CHAR_M				1685
#define IMG_STEEL_CHAR_N				1686
#define IMG_STEEL_CHAR_O				1687
#define IMG_STEEL_CHAR_P				1688
#define IMG_STEEL_CHAR_Q				1689
#define IMG_STEEL_CHAR_R				1690
#define IMG_STEEL_CHAR_S				1691
#define IMG_STEEL_CHAR_T				1692
#define IMG_STEEL_CHAR_U				1693
#define IMG_STEEL_CHAR_V				1694
#define IMG_STEEL_CHAR_W				1695
#define IMG_STEEL_CHAR_X				1696
#define IMG_STEEL_CHAR_Y				1697
#define IMG_STEEL_CHAR_Z				1698
#define IMG_STEEL_CHAR_BRACKETLEFT			1699
#define IMG_STEEL_CHAR_BACKSLASH			1700
#define IMG_STEEL_CHAR_BRACKETRIGHT			1701
#define IMG_STEEL_CHAR_ASCIICIRCUM			1702
#define IMG_STEEL_CHAR_UNDERSCORE			1703
#define IMG_STEEL_CHAR_COPYRIGHT			1704
#define IMG_STEEL_CHAR_AUMLAUT				1705
#define IMG_STEEL_CHAR_OUMLAUT				1706
#define IMG_STEEL_CHAR_UUMLAUT				1707
#define IMG_STEEL_CHAR_DEGREE				1708
#define IMG_STEEL_CHAR_TRADEMARK			1709
#define IMG_STEEL_CHAR_CURSOR				1710
#define IMG_STEEL_CHAR_BUTTON				1711
#define IMG_STEEL_CHAR_UP				1712
#define IMG_STEEL_CHAR_DOWN				1713
#define IMG_CUSTOM_1					1714
#define IMG_CUSTOM_1_EDITOR				1715
#define IMG_CUSTOM_2					1716
#define IMG_CUSTOM_2_EDITOR				1717
#define IMG_CUSTOM_3					1718
#define IMG_CUSTOM_3_EDITOR				1719
#define IMG_CUSTOM_4					1720
#define IMG_CUSTOM_4_EDITOR				1721
#define IMG_CUSTOM_5					1722
#define IMG_CUSTOM_5_EDITOR				1723
#define IMG_CUSTOM_6					1724
#define IMG_CUSTOM_6_EDITOR				1725
#define IMG_CUSTOM_7					1726
#define IMG_CUSTOM_7_EDITOR				1727
#define IMG_CUSTOM_8					1728
#define IMG_CUSTOM_8_EDITOR				1729
#define IMG_CUSTOM_9					1730
#define IMG_CUSTOM_9_EDITOR				1731
#define IMG_CUSTOM_10					1732
#define IMG_CUSTOM_10_EDITOR				1733
#define IMG_CUSTOM_11					1734
#define IMG_CUSTOM_11_EDITOR				1735
#define IMG_CUSTOM_12					1736
#define IMG_CUSTOM_12_EDITOR				1737
#define IMG_CUSTOM_13					1738
#define IMG_CUSTOM_13_EDITOR				1739
#define IMG_CUSTOM_14					1740
#define IMG_CUSTOM_14_EDITOR				1741
#define IMG_CUSTOM_15					1742
#define IMG_CUSTOM_15_EDITOR				1743
#define IMG_CUSTOM_16					1744
#define IMG_CUSTOM_16_EDITOR				1745
#define IMG_CUSTOM_17					1746
#define IMG_CUSTOM_17_EDITOR				1747
#define IMG_CUSTOM_18					1748
#define IMG_CUSTOM_18_EDITOR				1749
#define IMG_CUSTOM_19					1750
#define IMG_CUSTOM_19_EDITOR				1751
#define IMG_CUSTOM_20					1752
#define IMG_CUSTOM_20_EDITOR				1753
#define IMG_CUSTOM_21					1754
#define IMG_CUSTOM_21_EDITOR				1755
#define IMG_CUSTOM_22					1756
#define IMG_CUSTOM_22_EDITOR				1757
#define IMG_CUSTOM_23					1758
#define IMG_CUSTOM_23_EDITOR				1759
#define IMG_CUSTOM_24					1760
#define IMG_CUSTOM_24_EDITOR				1761
#define IMG_CUSTOM_25					1762
#define IMG_CUSTOM_25_EDITOR				1763
#define IMG_CUSTOM_26					1764
#define IMG_CUSTOM_26_EDITOR				1765
#define IMG_CUSTOM_27					1766
#define IMG_CUSTOM_27_EDITOR				1767
#define IMG_CUSTOM_28					1768
#define IMG_CUSTOM_28_EDITOR				1769
#define IMG_CUSTOM_29					1770
#define IMG_CUSTOM_29_EDITOR				1771
#define IMG_CUSTOM_30					1772
#define IMG_CUSTOM_30_EDITOR				1773
#define IMG_CUSTOM_31					1774
#define IMG_CUSTOM_31_EDITOR				1775
#define IMG_CUSTOM_32					1776
#define IMG_CUSTOM_32_EDITOR				1777
#define IMG_CUSTOM_33					1778
#define IMG_CUSTOM_33_EDITOR				1779
#define IMG_CUSTOM_34					1780
#define IMG_CUSTOM_34_EDITOR				1781
#define IMG_CUSTOM_35					1782
#define IMG_CUSTOM_35_EDITOR				1783
#define IMG_CUSTOM_36					1784
#define IMG_CUSTOM_36_EDITOR				1785
#define IMG_CUSTOM_37					1786
#define IMG_CUSTOM_37_EDITOR				1787
#define IMG_CUSTOM_38					1788
#define IMG_CUSTOM_38_EDITOR				1789
#define IMG_CUSTOM_39					1790
#define IMG_CUSTOM_39_EDITOR				1791
#define IMG_CUSTOM_40					1792
#define IMG_CUSTOM_40_EDITOR				1793
#define IMG_CUSTOM_41					1794
#define IMG_CUSTOM_41_EDITOR				1795
#define IMG_CUSTOM_42					1796
#define IMG_CUSTOM_42_EDITOR				1797
#define IMG_CUSTOM_43					1798
#define IMG_CUSTOM_43_EDITOR				1799
#define IMG_CUSTOM_44					1800
#define IMG_CUSTOM_44_EDITOR				1801
#define IMG_CUSTOM_45					1802
#define IMG_CUSTOM_45_EDITOR				1803
#define IMG_CUSTOM_46					1804
#define IMG_CUSTOM_46_EDITOR				1805
#define IMG_CUSTOM_47					1806
#define IMG_CUSTOM_47_EDITOR				1807
#define IMG_CUSTOM_48					1808
#define IMG_CUSTOM_48_EDITOR				1809
#define IMG_CUSTOM_49					1810
#define IMG_CUSTOM_49_EDITOR				1811
#define IMG_CUSTOM_50					1812
#define IMG_CUSTOM_50_EDITOR				1813
#define IMG_CUSTOM_51					1814
#define IMG_CUSTOM_51_EDITOR				1815
#define IMG_CUSTOM_52					1816
#define IMG_CUSTOM_52_EDITOR				1817
#define IMG_CUSTOM_53					1818
#define IMG_CUSTOM_53_EDITOR				1819
#define IMG_CUSTOM_54					1820
#define IMG_CUSTOM_54_EDITOR				1821
#define IMG_CUSTOM_55					1822
#define IMG_CUSTOM_55_EDITOR				1823
#define IMG_CUSTOM_56					1824
#define IMG_CUSTOM_56_EDITOR				1825
#define IMG_CUSTOM_57					1826
#define IMG_CUSTOM_57_EDITOR				1827
#define IMG_CUSTOM_58					1828
#define IMG_CUSTOM_58_EDITOR				1829
#define IMG_CUSTOM_59					1830
#define IMG_CUSTOM_59_EDITOR				1831
#define IMG_CUSTOM_60					1832
#define IMG_CUSTOM_60_EDITOR				1833
#define IMG_CUSTOM_61					1834
#define IMG_CUSTOM_61_EDITOR				1835
#define IMG_CUSTOM_62					1836
#define IMG_CUSTOM_62_EDITOR				1837
#define IMG_CUSTOM_63					1838
#define IMG_CUSTOM_63_EDITOR				1839
#define IMG_CUSTOM_64					1840
#define IMG_CUSTOM_64_EDITOR				1841
#define IMG_CUSTOM_65					1842
#define IMG_CUSTOM_65_EDITOR				1843
#define IMG_CUSTOM_66					1844
#define IMG_CUSTOM_66_EDITOR				1845
#define IMG_CUSTOM_67					1846
#define IMG_CUSTOM_67_EDITOR				1847
#define IMG_CUSTOM_68					1848
#define IMG_CUSTOM_68_EDITOR				1849
#define IMG_CUSTOM_69					1850
#define IMG_CUSTOM_69_EDITOR				1851
#define IMG_CUSTOM_70					1852
#define IMG_CUSTOM_70_EDITOR				1853
#define IMG_CUSTOM_71					1854
#define IMG_CUSTOM_71_EDITOR				1855
#define IMG_CUSTOM_72					1856
#define IMG_CUSTOM_72_EDITOR				1857
#define IMG_CUSTOM_73					1858
#define IMG_CUSTOM_73_EDITOR				1859
#define IMG_CUSTOM_74					1860
#define IMG_CUSTOM_74_EDITOR				1861
#define IMG_CUSTOM_75					1862
#define IMG_CUSTOM_75_EDITOR				1863
#define IMG_CUSTOM_76					1864
#define IMG_CUSTOM_76_EDITOR				1865
#define IMG_CUSTOM_77					1866
#define IMG_CUSTOM_77_EDITOR				1867
#define IMG_CUSTOM_78					1868
#define IMG_CUSTOM_78_EDITOR				1869
#define IMG_CUSTOM_79					1870
#define IMG_CUSTOM_79_EDITOR				1871
#define IMG_CUSTOM_80					1872
#define IMG_CUSTOM_80_EDITOR				1873
#define IMG_CUSTOM_81					1874
#define IMG_CUSTOM_81_EDITOR				1875
#define IMG_CUSTOM_82					1876
#define IMG_CUSTOM_82_EDITOR				1877
#define IMG_CUSTOM_83					1878
#define IMG_CUSTOM_83_EDITOR				1879
#define IMG_CUSTOM_84					1880
#define IMG_CUSTOM_84_EDITOR				1881
#define IMG_CUSTOM_85					1882
#define IMG_CUSTOM_85_EDITOR				1883
#define IMG_CUSTOM_86					1884
#define IMG_CUSTOM_86_EDITOR				1885
#define IMG_CUSTOM_87					1886
#define IMG_CUSTOM_87_EDITOR				1887
#define IMG_CUSTOM_88					1888
#define IMG_CUSTOM_88_EDITOR				1889
#define IMG_CUSTOM_89					1890
#define IMG_CUSTOM_89_EDITOR				1891
#define IMG_CUSTOM_90					1892
#define IMG_CUSTOM_90_EDITOR				1893
#define IMG_CUSTOM_91					1894
#define IMG_CUSTOM_91_EDITOR				1895
#define IMG_CUSTOM_92					1896
#define IMG_CUSTOM_92_EDITOR				1897
#define IMG_CUSTOM_93					1898
#define IMG_CUSTOM_93_EDITOR				1899
#define IMG_CUSTOM_94					1900
#define IMG_CUSTOM_94_EDITOR				1901
#define IMG_CUSTOM_95					1902
#define IMG_CUSTOM_95_EDITOR				1903
#define IMG_CUSTOM_96					1904
#define IMG_CUSTOM_96_EDITOR				1905
#define IMG_CUSTOM_97					1906
#define IMG_CUSTOM_97_EDITOR				1907
#define IMG_CUSTOM_98					1908
#define IMG_CUSTOM_98_EDITOR				1909
#define IMG_CUSTOM_99					1910
#define IMG_CUSTOM_99_EDITOR				1911
#define IMG_CUSTOM_100					1912
#define IMG_CUSTOM_100_EDITOR				1913
#define IMG_CUSTOM_101					1914
#define IMG_CUSTOM_101_EDITOR				1915
#define IMG_CUSTOM_102					1916
#define IMG_CUSTOM_102_EDITOR				1917
#define IMG_CUSTOM_103					1918
#define IMG_CUSTOM_103_EDITOR				1919
#define IMG_CUSTOM_104					1920
#define IMG_CUSTOM_104_EDITOR				1921
#define IMG_CUSTOM_105					1922
#define IMG_CUSTOM_105_EDITOR				1923
#define IMG_CUSTOM_106					1924
#define IMG_CUSTOM_106_EDITOR				1925
#define IMG_CUSTOM_107					1926
#define IMG_CUSTOM_107_EDITOR				1927
#define IMG_CUSTOM_108					1928
#define IMG_CUSTOM_108_EDITOR				1929
#define IMG_CUSTOM_109					1930
#define IMG_CUSTOM_109_EDITOR				1931
#define IMG_CUSTOM_110					1932
#define IMG_CUSTOM_110_EDITOR				1933
#define IMG_CUSTOM_111					1934
#define IMG_CUSTOM_111_EDITOR				1935
#define IMG_CUSTOM_112					1936
#define IMG_CUSTOM_112_EDITOR				1937
#define IMG_CUSTOM_113					1938
#define IMG_CUSTOM_113_EDITOR				1939
#define IMG_CUSTOM_114					1940
#define IMG_CUSTOM_114_EDITOR				1941
#define IMG_CUSTOM_115					1942
#define IMG_CUSTOM_115_EDITOR				1943
#define IMG_CUSTOM_116					1944
#define IMG_CUSTOM_116_EDITOR				1945
#define IMG_CUSTOM_117					1946
#define IMG_CUSTOM_117_EDITOR				1947
#define IMG_CUSTOM_118					1948
#define IMG_CUSTOM_118_EDITOR				1949
#define IMG_CUSTOM_119					1950
#define IMG_CUSTOM_119_EDITOR				1951
#define IMG_CUSTOM_120					1952
#define IMG_CUSTOM_120_EDITOR				1953
#define IMG_CUSTOM_121					1954
#define IMG_CUSTOM_121_EDITOR				1955
#define IMG_CUSTOM_122					1956
#define IMG_CUSTOM_122_EDITOR				1957
#define IMG_CUSTOM_123					1958
#define IMG_CUSTOM_123_EDITOR				1959
#define IMG_CUSTOM_124					1960
#define IMG_CUSTOM_124_EDITOR				1961
#define IMG_CUSTOM_125					1962
#define IMG_CUSTOM_125_EDITOR				1963
#define IMG_CUSTOM_126					1964
#define IMG_CUSTOM_126_EDITOR				1965
#define IMG_CUSTOM_127					1966
#define IMG_CUSTOM_127_EDITOR				1967
#define IMG_CUSTOM_128					1968
#define IMG_CUSTOM_128_EDITOR				1969
#define IMG_CUSTOM_129					1970
#define IMG_CUSTOM_129_EDITOR				1971
#define IMG_CUSTOM_130					1972
#define IMG_CUSTOM_130_EDITOR				1973
#define IMG_CUSTOM_131					1974
#define IMG_CUSTOM_131_EDITOR				1975
#define IMG_CUSTOM_132					1976
#define IMG_CUSTOM_132_EDITOR				1977
#define IMG_CUSTOM_133					1978
#define IMG_CUSTOM_133_EDITOR				1979
#define IMG_CUSTOM_134					1980
#define IMG_CUSTOM_134_EDITOR				1981
#define IMG_CUSTOM_135					1982
#define IMG_CUSTOM_135_EDITOR				1983
#define IMG_CUSTOM_136					1984
#define IMG_CUSTOM_136_EDITOR				1985
#define IMG_CUSTOM_137					1986
#define IMG_CUSTOM_137_EDITOR				1987
#define IMG_CUSTOM_138					1988
#define IMG_CUSTOM_138_EDITOR				1989
#define IMG_CUSTOM_139					1990
#define IMG_CUSTOM_139_EDITOR				1991
#define IMG_CUSTOM_140					1992
#define IMG_CUSTOM_140_EDITOR				1993
#define IMG_CUSTOM_141					1994
#define IMG_CUSTOM_141_EDITOR				1995
#define IMG_CUSTOM_142					1996
#define IMG_CUSTOM_142_EDITOR				1997
#define IMG_CUSTOM_143					1998
#define IMG_CUSTOM_143_EDITOR				1999
#define IMG_CUSTOM_144					2000
#define IMG_CUSTOM_144_EDITOR				2001
#define IMG_CUSTOM_145					2002
#define IMG_CUSTOM_145_EDITOR				2003
#define IMG_CUSTOM_146					2004
#define IMG_CUSTOM_146_EDITOR				2005
#define IMG_CUSTOM_147					2006
#define IMG_CUSTOM_147_EDITOR				2007
#define IMG_CUSTOM_148					2008
#define IMG_CUSTOM_148_EDITOR				2009
#define IMG_CUSTOM_149					2010
#define IMG_CUSTOM_149_EDITOR				2011
#define IMG_CUSTOM_150					2012
#define IMG_CUSTOM_150_EDITOR				2013
#define IMG_CUSTOM_151					2014
#define IMG_CUSTOM_151_EDITOR				2015
#define IMG_CUSTOM_152					2016
#define IMG_CUSTOM_152_EDITOR				2017
#define IMG_CUSTOM_153					2018
#define IMG_CUSTOM_153_EDITOR				2019
#define IMG_CUSTOM_154					2020
#define IMG_CUSTOM_154_EDITOR				2021
#define IMG_CUSTOM_155					2022
#define IMG_CUSTOM_155_EDITOR				2023
#define IMG_CUSTOM_156					2024
#define IMG_CUSTOM_156_EDITOR				2025
#define IMG_CUSTOM_157					2026
#define IMG_CUSTOM_157_EDITOR				2027
#define IMG_CUSTOM_158					2028
#define IMG_CUSTOM_158_EDITOR				2029
#define IMG_CUSTOM_159					2030
#define IMG_CUSTOM_159_EDITOR				2031
#define IMG_CUSTOM_160					2032
#define IMG_CUSTOM_160_EDITOR				2033
#define IMG_CUSTOM_161					2034
#define IMG_CUSTOM_161_EDITOR				2035
#define IMG_CUSTOM_162					2036
#define IMG_CUSTOM_162_EDITOR				2037
#define IMG_CUSTOM_163					2038
#define IMG_CUSTOM_163_EDITOR				2039
#define IMG_CUSTOM_164					2040
#define IMG_CUSTOM_164_EDITOR				2041
#define IMG_CUSTOM_165					2042
#define IMG_CUSTOM_165_EDITOR				2043
#define IMG_CUSTOM_166					2044
#define IMG_CUSTOM_166_EDITOR				2045
#define IMG_CUSTOM_167					2046
#define IMG_CUSTOM_167_EDITOR				2047
#define IMG_CUSTOM_168					2048
#define IMG_CUSTOM_168_EDITOR				2049
#define IMG_CUSTOM_169					2050
#define IMG_CUSTOM_169_EDITOR				2051
#define IMG_CUSTOM_170					2052
#define IMG_CUSTOM_170_EDITOR				2053
#define IMG_CUSTOM_171					2054
#define IMG_CUSTOM_171_EDITOR				2055
#define IMG_CUSTOM_172					2056
#define IMG_CUSTOM_172_EDITOR				2057
#define IMG_CUSTOM_173					2058
#define IMG_CUSTOM_173_EDITOR				2059
#define IMG_CUSTOM_174					2060
#define IMG_CUSTOM_174_EDITOR				2061
#define IMG_CUSTOM_175					2062
#define IMG_CUSTOM_175_EDITOR				2063
#define IMG_CUSTOM_176					2064
#define IMG_CUSTOM_176_EDITOR				2065
#define IMG_CUSTOM_177					2066
#define IMG_CUSTOM_177_EDITOR				2067
#define IMG_CUSTOM_178					2068
#define IMG_CUSTOM_178_EDITOR				2069
#define IMG_CUSTOM_179					2070
#define IMG_CUSTOM_179_EDITOR				2071
#define IMG_CUSTOM_180					2072
#define IMG_CUSTOM_180_EDITOR				2073
#define IMG_CUSTOM_181					2074
#define IMG_CUSTOM_181_EDITOR				2075
#define IMG_CUSTOM_182					2076
#define IMG_CUSTOM_182_EDITOR				2077
#define IMG_CUSTOM_183					2078
#define IMG_CUSTOM_183_EDITOR				2079
#define IMG_CUSTOM_184					2080
#define IMG_CUSTOM_184_EDITOR				2081
#define IMG_CUSTOM_185					2082
#define IMG_CUSTOM_185_EDITOR				2083
#define IMG_CUSTOM_186					2084
#define IMG_CUSTOM_186_EDITOR				2085
#define IMG_CUSTOM_187					2086
#define IMG_CUSTOM_187_EDITOR				2087
#define IMG_CUSTOM_188					2088
#define IMG_CUSTOM_188_EDITOR				2089
#define IMG_CUSTOM_189					2090
#define IMG_CUSTOM_189_EDITOR				2091
#define IMG_CUSTOM_190					2092
#define IMG_CUSTOM_190_EDITOR				2093
#define IMG_CUSTOM_191					2094
#define IMG_CUSTOM_191_EDITOR				2095
#define IMG_CUSTOM_192					2096
#define IMG_CUSTOM_192_EDITOR				2097
#define IMG_CUSTOM_193					2098
#define IMG_CUSTOM_193_EDITOR				2099
#define IMG_CUSTOM_194					2100
#define IMG_CUSTOM_194_EDITOR				2101
#define IMG_CUSTOM_195					2102
#define IMG_CUSTOM_195_EDITOR				2103
#define IMG_CUSTOM_196					2104
#define IMG_CUSTOM_196_EDITOR				2105
#define IMG_CUSTOM_197					2106
#define IMG_CUSTOM_197_EDITOR				2107
#define IMG_CUSTOM_198					2108
#define IMG_CUSTOM_198_EDITOR				2109
#define IMG_CUSTOM_199					2110
#define IMG_CUSTOM_199_EDITOR				2111
#define IMG_CUSTOM_200					2112
#define IMG_CUSTOM_200_EDITOR				2113
#define IMG_CUSTOM_201					2114
#define IMG_CUSTOM_201_EDITOR				2115
#define IMG_CUSTOM_202					2116
#define IMG_CUSTOM_202_EDITOR				2117
#define IMG_CUSTOM_203					2118
#define IMG_CUSTOM_203_EDITOR				2119
#define IMG_CUSTOM_204					2120
#define IMG_CUSTOM_204_EDITOR				2121
#define IMG_CUSTOM_205					2122
#define IMG_CUSTOM_205_EDITOR				2123
#define IMG_CUSTOM_206					2124
#define IMG_CUSTOM_206_EDITOR				2125
#define IMG_CUSTOM_207					2126
#define IMG_CUSTOM_207_EDITOR				2127
#define IMG_CUSTOM_208					2128
#define IMG_CUSTOM_208_EDITOR				2129
#define IMG_CUSTOM_209					2130
#define IMG_CUSTOM_209_EDITOR				2131
#define IMG_CUSTOM_210					2132
#define IMG_CUSTOM_210_EDITOR				2133
#define IMG_CUSTOM_211					2134
#define IMG_CUSTOM_211_EDITOR				2135
#define IMG_CUSTOM_212					2136
#define IMG_CUSTOM_212_EDITOR				2137
#define IMG_CUSTOM_213					2138
#define IMG_CUSTOM_213_EDITOR				2139
#define IMG_CUSTOM_214					2140
#define IMG_CUSTOM_214_EDITOR				2141
#define IMG_CUSTOM_215					2142
#define IMG_CUSTOM_215_EDITOR				2143
#define IMG_CUSTOM_216					2144
#define IMG_CUSTOM_216_EDITOR				2145
#define IMG_CUSTOM_217					2146
#define IMG_CUSTOM_217_EDITOR				2147
#define IMG_CUSTOM_218					2148
#define IMG_CUSTOM_218_EDITOR				2149
#define IMG_CUSTOM_219					2150
#define IMG_CUSTOM_219_EDITOR				2151
#define IMG_CUSTOM_220					2152
#define IMG_CUSTOM_220_EDITOR				2153
#define IMG_CUSTOM_221					2154
#define IMG_CUSTOM_221_EDITOR				2155
#define IMG_CUSTOM_222					2156
#define IMG_CUSTOM_222_EDITOR				2157
#define IMG_CUSTOM_223					2158
#define IMG_CUSTOM_223_EDITOR				2159
#define IMG_CUSTOM_224					2160
#define IMG_CUSTOM_224_EDITOR				2161
#define IMG_CUSTOM_225					2162
#define IMG_CUSTOM_225_EDITOR				2163
#define IMG_CUSTOM_226					2164
#define IMG_CUSTOM_226_EDITOR				2165
#define IMG_CUSTOM_227					2166
#define IMG_CUSTOM_227_EDITOR				2167
#define IMG_CUSTOM_228					2168
#define IMG_CUSTOM_228_EDITOR				2169
#define IMG_CUSTOM_229					2170
#define IMG_CUSTOM_229_EDITOR				2171
#define IMG_CUSTOM_230					2172
#define IMG_CUSTOM_230_EDITOR				2173
#define IMG_CUSTOM_231					2174
#define IMG_CUSTOM_231_EDITOR				2175
#define IMG_CUSTOM_232					2176
#define IMG_CUSTOM_232_EDITOR				2177
#define IMG_CUSTOM_233					2178
#define IMG_CUSTOM_233_EDITOR				2179
#define IMG_CUSTOM_234					2180
#define IMG_CUSTOM_234_EDITOR				2181
#define IMG_CUSTOM_235					2182
#define IMG_CUSTOM_235_EDITOR				2183
#define IMG_CUSTOM_236					2184
#define IMG_CUSTOM_236_EDITOR				2185
#define IMG_CUSTOM_237					2186
#define IMG_CUSTOM_237_EDITOR				2187
#define IMG_CUSTOM_238					2188
#define IMG_CUSTOM_238_EDITOR				2189
#define IMG_CUSTOM_239					2190
#define IMG_CUSTOM_239_EDITOR				2191
#define IMG_CUSTOM_240					2192
#define IMG_CUSTOM_240_EDITOR				2193
#define IMG_CUSTOM_241					2194
#define IMG_CUSTOM_241_EDITOR				2195
#define IMG_CUSTOM_242					2196
#define IMG_CUSTOM_242_EDITOR				2197
#define IMG_CUSTOM_243					2198
#define IMG_CUSTOM_243_EDITOR				2199
#define IMG_CUSTOM_244					2200
#define IMG_CUSTOM_244_EDITOR				2201
#define IMG_CUSTOM_245					2202
#define IMG_CUSTOM_245_EDITOR				2203
#define IMG_CUSTOM_246					2204
#define IMG_CUSTOM_246_EDITOR				2205
#define IMG_CUSTOM_247					2206
#define IMG_CUSTOM_247_EDITOR				2207
#define IMG_CUSTOM_248					2208
#define IMG_CUSTOM_248_EDITOR				2209
#define IMG_CUSTOM_249					2210
#define IMG_CUSTOM_249_EDITOR				2211
#define IMG_CUSTOM_250					2212
#define IMG_CUSTOM_250_EDITOR				2213
#define IMG_CUSTOM_251					2214
#define IMG_CUSTOM_251_EDITOR				2215
#define IMG_CUSTOM_252					2216
#define IMG_CUSTOM_252_EDITOR				2217
#define IMG_CUSTOM_253					2218
#define IMG_CUSTOM_253_EDITOR				2219
#define IMG_CUSTOM_254					2220
#define IMG_CUSTOM_254_EDITOR				2221
#define IMG_CUSTOM_255					2222
#define IMG_CUSTOM_255_EDITOR				2223
#define IMG_CUSTOM_256					2224
#define IMG_CUSTOM_256_EDITOR				2225
#define IMG_GROUP_1					2226
#define IMG_GROUP_1_EDITOR				2227
#define IMG_GROUP_2					2228
#define IMG_GROUP_2_EDITOR				2229
#define IMG_GROUP_3					2230
#define IMG_GROUP_3_EDITOR				2231
#define IMG_GROUP_4					2232
#define IMG_GROUP_4_EDITOR				2233
#define IMG_GROUP_5					2234
#define IMG_GROUP_5_EDITOR				2235
#define IMG_GROUP_6					2236
#define IMG_GROUP_6_EDITOR				2237
#define IMG_GROUP_7					2238
#define IMG_GROUP_7_EDITOR				2239
#define IMG_GROUP_8					2240
#define IMG_GROUP_8_EDITOR				2241
#define IMG_GROUP_9					2242
#define IMG_GROUP_9_EDITOR				2243
#define IMG_GROUP_10					2244
#define IMG_GROUP_10_EDITOR				2245
#define IMG_GROUP_11					2246
#define IMG_GROUP_11_EDITOR				2247
#define IMG_GROUP_12					2248
#define IMG_GROUP_12_EDITOR				2249
#define IMG_GROUP_13					2250
#define IMG_GROUP_13_EDITOR				2251
#define IMG_GROUP_14					2252
#define IMG_GROUP_14_EDITOR				2253
#define IMG_GROUP_15					2254
#define IMG_GROUP_15_EDITOR				2255
#define IMG_GROUP_16					2256
#define IMG_GROUP_16_EDITOR				2257
#define IMG_GROUP_17					2258
#define IMG_GROUP_17_EDITOR				2259
#define IMG_GROUP_18					2260
#define IMG_GROUP_18_EDITOR				2261
#define IMG_GROUP_19					2262
#define IMG_GROUP_19_EDITOR				2263
#define IMG_GROUP_20					2264
#define IMG_GROUP_20_EDITOR				2265
#define IMG_GROUP_21					2266
#define IMG_GROUP_21_EDITOR				2267
#define IMG_GROUP_22					2268
#define IMG_GROUP_22_EDITOR				2269
#define IMG_GROUP_23					2270
#define IMG_GROUP_23_EDITOR				2271
#define IMG_GROUP_24					2272
#define IMG_GROUP_24_EDITOR				2273
#define IMG_GROUP_25					2274
#define IMG_GROUP_25_EDITOR				2275
#define IMG_GROUP_26					2276
#define IMG_GROUP_26_EDITOR				2277
#define IMG_GROUP_27					2278
#define IMG_GROUP_27_EDITOR				2279
#define IMG_GROUP_28					2280
#define IMG_GROUP_28_EDITOR				2281
#define IMG_GROUP_29					2282
#define IMG_GROUP_29_EDITOR				2283
#define IMG_GROUP_30					2284
#define IMG_GROUP_30_EDITOR				2285
#define IMG_GROUP_31					2286
#define IMG_GROUP_31_EDITOR				2287
#define IMG_GROUP_32					2288
#define IMG_GROUP_32_EDITOR				2289
#define IMG_EMPTY_SPACE_1				2290
#define IMG_EMPTY_SPACE_1_EDITOR			2291
#define IMG_EMPTY_SPACE_2				2292
#define IMG_EMPTY_SPACE_2_EDITOR			2293
#define IMG_EMPTY_SPACE_3				2294
#define IMG_EMPTY_SPACE_3_EDITOR			2295
#define IMG_EMPTY_SPACE_4				2296
#define IMG_EMPTY_SPACE_4_EDITOR			2297
#define IMG_EMPTY_SPACE_5				2298
#define IMG_EMPTY_SPACE_5_EDITOR			2299
#define IMG_EMPTY_SPACE_6				2300
#define IMG_EMPTY_SPACE_6_EDITOR			2301
#define IMG_EMPTY_SPACE_7				2302
#define IMG_EMPTY_SPACE_7_EDITOR			2303
#define IMG_EMPTY_SPACE_8				2304
#define IMG_EMPTY_SPACE_8_EDITOR			2305
#define IMG_EMPTY_SPACE_9				2306
#define IMG_EMPTY_SPACE_9_EDITOR			2307
#define IMG_EMPTY_SPACE_10				2308
#define IMG_EMPTY_SPACE_10_EDITOR			2309
#define IMG_EMPTY_SPACE_11				2310
#define IMG_EMPTY_SPACE_11_EDITOR			2311
#define IMG_EMPTY_SPACE_12				2312
#define IMG_EMPTY_SPACE_12_EDITOR			2313
#define IMG_EMPTY_SPACE_13				2314
#define IMG_EMPTY_SPACE_13_EDITOR			2315
#define IMG_EMPTY_SPACE_14				2316
#define IMG_EMPTY_SPACE_14_EDITOR			2317
#define IMG_EMPTY_SPACE_15				2318
#define IMG_EMPTY_SPACE_15_EDITOR			2319
#define IMG_EMPTY_SPACE_16				2320
#define IMG_EMPTY_SPACE_16_EDITOR			2321
#define IMG_SP_FRAME_HORIZONTAL				2322
#define IMG_SP_FRAME_VERTICAL				2323
#define IMG_SP_FRAME_CORNER				2324
#define IMG_TOON_1					2325
#define IMG_TOON_2					2326
#define IMG_TOON_3					2327
#define IMG_TOON_4					2328
#define IMG_TOON_5					2329
#define IMG_TOON_6					2330
#define IMG_TOON_7					2331
#define IMG_TOON_8					2332
#define IMG_TOON_9					2333
#define IMG_TOON_10					2334
#define IMG_TOON_11					2335
#define IMG_TOON_12					2336
#define IMG_TOON_13					2337
#define IMG_TOON_14					2338
#define IMG_TOON_15					2339
#define IMG_TOON_16					2340
#define IMG_TOON_17					2341
#define IMG_TOON_18					2342
#define IMG_TOON_19					2343
#define IMG_TOON_20					2344
#define IMG_GFX_GLOBAL_ANIM_1				2345
#define IMG_GFX_GLOBAL_ANIM_2				2346
#define IMG_GFX_GLOBAL_ANIM_3				2347
#define IMG_GFX_GLOBAL_ANIM_4				2348
#define IMG_GFX_GLOBAL_ANIM_5				2349
#define IMG_GFX_GLOBAL_ANIM_6				2350
#define IMG_GFX_GLOBAL_ANIM_7				2351
#define IMG_GFX_GLOBAL_ANIM_8				2352
#define IMG_GFX_GLOBAL_ANIM_9				2353
#define IMG_GFX_GLOBAL_ANIM_10				2354
#define IMG_GFX_GLOBAL_ANIM_11				2355
#define IMG_GFX_GLOBAL_ANIM_12				2356
#define IMG_GFX_GLOBAL_ANIM_13				2357
#define IMG_GFX_GLOBAL_ANIM_14				2358
#define IMG_GFX_GLOBAL_ANIM_15				2359
#define IMG_GFX_GLOBAL_ANIM_16				2360
#define IMG_GFX_GLOBAL_ANIM_17				2361
#define IMG_GFX_GLOBAL_ANIM_18				2362
#define IMG_GFX_GLOBAL_ANIM_19				2363
#define IMG_GFX_GLOBAL_ANIM_20				2364
#define IMG_GFX_GLOBAL_ANIM_21				2365
#define IMG_GFX_GLOBAL_ANIM_22				2366
#define IMG_GFX_GLOBAL_ANIM_23				2367
#define IMG_GFX_GLOBAL_ANIM_24				2368
#define IMG_GFX_GLOBAL_ANIM_25				2369
#define IMG_GFX_GLOBAL_ANIM_26				2370
#define IMG_GFX_GLOBAL_ANIM_27				2371
#define IMG_GFX_GLOBAL_ANIM_28				2372
#define IMG_GFX_GLOBAL_ANIM_29				2373
#define IMG_GFX_GLOBAL_ANIM_30				2374
#define IMG_GFX_GLOBAL_ANIM_31				2375
#define IMG_GFX_GLOBAL_ANIM_32				2376
#define IMG_GLOBAL_ANIM_1				2377
#define IMG_GLOBAL_ANIM_2				2378
#define IMG_GLOBAL_ANIM_3				2379
#define IMG_GLOBAL_ANIM_4				2380
#define IMG_GLOBAL_ANIM_5				2381
#define IMG_GLOBAL_ANIM_6				2382
#define IMG_GLOBAL_ANIM_7				2383
#define IMG_GLOBAL_ANIM_8				2384
#define IMG_GLOBAL_ANIM_9				2385
#define IMG_GLOBAL_ANIM_10				2386
#define IMG_GLOBAL_ANIM_11				2387
#define IMG_GLOBAL_ANIM_12				2388
#define IMG_GLOBAL_ANIM_13				2389
#define IMG_GLOBAL_ANIM_14				2390
#define IMG_GLOBAL_ANIM_15				2391
#define IMG_GLOBAL_ANIM_16				2392
#define IMG_GLOBAL_ANIM_17				2393
#define IMG_GLOBAL_ANIM_18				2394
#define IMG_GLOBAL_ANIM_19				2395
#define IMG_GLOBAL_ANIM_20				2396
#define IMG_GLOBAL_ANIM_21				2397
#define IMG_GLOBAL_ANIM_22				2398
#define IMG_GLOBAL_ANIM_23				2399
#define IMG_GLOBAL_ANIM_24				2400
#define IMG_GLOBAL_ANIM_25				2401
#define IMG_GLOBAL_ANIM_26				2402
#define IMG_GLOBAL_ANIM_27				2403
#define IMG_GLOBAL_ANIM_28				2404
#define IMG_GLOBAL_ANIM_29				2405
#define IMG_GLOBAL_ANIM_30				2406
#define IMG_GLOBAL_ANIM_31				2407
#define IMG_GLOBAL_ANIM_32				2408
#define IMG_INTERNAL_GLOBAL_TOON_DEFAULT		2409
#define IMG_INTERNAL_GLOBAL_ANIM_DEFAULT		2410
#define IMG_MENU_CALIBRATE_RED				2411
#define IMG_MENU_CALIBRATE_BLUE				2412
#define IMG_MENU_CALIBRATE_YELLOW			2413
#define IMG_MENU_BUTTON					2414
#define IMG_MENU_BUTTON_ACTIVE				2415
#define IMG_MENU_BUTTON_LEFT				2416
#define IMG_MENU_BUTTON_LEFT_ACTIVE			2417
#define IMG_MENU_BUTTON_RIGHT				2418
#define IMG_MENU_BUTTON_RIGHT_ACTIVE			2419
#define IMG_MENU_BUTTON_UP				2420
#define IMG_MENU_BUTTON_UP_ACTIVE			2421
#define IMG_MENU_BUTTON_DOWN				2422
#define IMG_MENU_BUTTON_DOWN_ACTIVE			2423
#define IMG_MENU_BUTTON_ENTER_MENU			2424
#define IMG_MENU_BUTTON_ENTER_MENU_ACTIVE		2425
#define IMG_MENU_BUTTON_LEAVE_MENU			2426
#define IMG_MENU_BUTTON_LEAVE_MENU_ACTIVE		2427
#define IMG_MENU_BUTTON_NEXT_LEVEL			2428
#define IMG_MENU_BUTTON_NEXT_LEVEL_ACTIVE		2429
#define IMG_MENU_BUTTON_PREV_LEVEL			2430
#define IMG_MENU_BUTTON_PREV_LEVEL_ACTIVE		2431
#define IMG_MENU_BUTTON_NEXT_LEVEL2			2432
#define IMG_MENU_BUTTON_NEXT_LEVEL2_ACTIVE		2433
#define IMG_MENU_BUTTON_PREV_LEVEL2			2434
#define IMG_MENU_BUTTON_PREV_LEVEL2_ACTIVE		2435
#define IMG_MENU_BUTTON_NEXT_LEVEL3			2436
#define IMG_MENU_BUTTON_NEXT_LEVEL3_ACTIVE		2437
#define IMG_MENU_BUTTON_PREV_LEVEL3			2438
#define IMG_MENU_BUTTON_PREV_LEVEL3_ACTIVE		2439
#define IMG_MENU_BUTTON_NEXT_SCORE			2440
#define IMG_MENU_BUTTON_NEXT_SCORE_ACTIVE		2441
#define IMG_MENU_BUTTON_PREV_SCORE			2442
#define IMG_MENU_BUTTON_PREV_SCORE_ACTIVE		2443
#define IMG_MENU_BUTTON_PLAY_TAPE			2444
#define IMG_MENU_BUTTON_NAME				2445
#define IMG_MENU_BUTTON_NAME_ACTIVE			2446
#define IMG_MENU_BUTTON_LEVELS				2447
#define IMG_MENU_BUTTON_LEVELS_ACTIVE			2448
#define IMG_MENU_BUTTON_SCORES				2449
#define IMG_MENU_BUTTON_SCORES_ACTIVE			2450
#define IMG_MENU_BUTTON_EDITOR				2451
#define IMG_MENU_BUTTON_EDITOR_ACTIVE			2452
#define IMG_MENU_BUTTON_INFO				2453
#define IMG_MENU_BUTTON_INFO_ACTIVE			2454
#define IMG_MENU_BUTTON_GAME				2455
#define IMG_MENU_BUTTON_GAME_ACTIVE			2456
#define IMG_MENU_BUTTON_SETUP				2457
#define IMG_MENU_BUTTON_SETUP_ACTIVE			2458
#define IMG_MENU_BUTTON_QUIT				2459
#define IMG_MENU_BUTTON_QUIT_ACTIVE			2460
#define IMG_MENU_BUTTON_FIRST_LEVEL			2461
#define IMG_MENU_BUTTON_FIRST_LEVEL_ACTIVE		2462
#define IMG_MENU_BUTTON_LAST_LEVEL			2463
#define IMG_MENU_BUTTON_LAST_LEVEL_ACTIVE		2464
#define IMG_MENU_BUTTON_LEVEL_NUMBER			2465
#define IMG_MENU_BUTTON_LEVEL_NUMBER_ACTIVE		2466
#define IMG_MENU_BUTTON_INSERT_SOLUTION			2467
#define IMG_MENU_BUTTON_INSERT_SOLUTION_ACTIVE		2468
#define IMG_MENU_BUTTON_PLAY_SOLUTION			2469
#define IMG_MENU_BUTTON_PLAY_SOLUTION_ACTIVE		2470
#define IMG_MENU_BUTTON_LEVELSET_INFO			2471
#define IMG_MENU_BUTTON_LEVELSET_INFO_PRESSED		2472
#define IMG_MENU_BUTTON_LEVELSET_INFO_ACTIVE		2473
#define IMG_MENU_BUTTON_LEVEL_INFO			2474
#define IMG_MENU_BUTTON_LEVEL_INFO_PRESSED		2475
#define IMG_MENU_BUTTON_LEVEL_INFO_ACTIVE		2476
#define IMG_MENU_BUTTON_SWITCH_ECS_AGA			2477
#define IMG_MENU_BUTTON_SWITCH_ECS_AGA_ACTIVE		2478
#define IMG_MENU_BUTTON_TOUCH_BACK			2479
#define IMG_MENU_BUTTON_TOUCH_NEXT			2480
#define IMG_MENU_BUTTON_TOUCH_BACK2			2481
#define IMG_MENU_BUTTON_TOUCH_NEXT2			2482
#define IMG_MENU_SCROLL_UP				2483
#define IMG_MENU_SCROLL_UP_ACTIVE			2484
#define IMG_MENU_SCROLL_DOWN				2485
#define IMG_MENU_SCROLL_DOWN_ACTIVE			2486
#define IMG_MENU_SCROLLBAR				2487
#define IMG_MENU_SCROLLBAR_ACTIVE			2488
#define IMG_GFX_GAME_PANEL_TIME_ANIM			2489
#define IMG_GFX_GAME_PANEL_TIME_ANIM_ACTIVE		2490
#define IMG_GFX_GAME_PANEL_HEALTH_ANIM			2491
#define IMG_GFX_GAME_PANEL_HEALTH_ANIM_ACTIVE		2492
#define IMG_GFX_GAME_BUTTON_STOP			2493
#define IMG_GFX_GAME_BUTTON_PAUSE			2494
#define IMG_GFX_GAME_BUTTON_PLAY			2495
#define IMG_GFX_GAME_BUTTON_UNDO			2496
#define IMG_GFX_GAME_BUTTON_REDO			2497
#define IMG_GFX_GAME_BUTTON_SAVE			2498
#define IMG_GFX_GAME_BUTTON_PAUSE2			2499
#define IMG_GFX_GAME_BUTTON_LOAD			2500
#define IMG_GFX_GAME_BUTTON_RESTART			2501
#define IMG_GFX_GAME_BUTTON_SOUND_MUSIC			2502
#define IMG_GFX_GAME_BUTTON_SOUND_LOOPS			2503
#define IMG_GFX_GAME_BUTTON_SOUND_SIMPLE		2504
#define IMG_GFX_GAME_BUTTON_PANEL_STOP			2505
#define IMG_GFX_GAME_BUTTON_PANEL_PAUSE			2506
#define IMG_GFX_GAME_BUTTON_PANEL_PLAY			2507
#define IMG_GFX_GAME_BUTTON_PANEL_RESTART		2508
#define IMG_GFX_GAME_BUTTON_PANEL_SOUND_MUSIC		2509
#define IMG_GFX_GAME_BUTTON_PANEL_SOUND_LOOPS		2510
#define IMG_GFX_GAME_BUTTON_PANEL_SOUND_SIMPLE		2511
#define IMG_GFX_GAME_BUTTON_TOUCH_STOP			2512
#define IMG_GFX_GAME_BUTTON_TOUCH_PAUSE			2513
#define IMG_GFX_GAME_BUTTON_TOUCH_RESTART		2514
#define IMG_GFX_TAPE_BUTTON_EJECT			2515
#define IMG_GFX_TAPE_BUTTON_EXTRA			2516
#define IMG_GFX_TAPE_BUTTON_STOP			2517
#define IMG_GFX_TAPE_BUTTON_PAUSE			2518
#define IMG_GFX_TAPE_BUTTON_RECORD			2519
#define IMG_GFX_TAPE_BUTTON_PLAY			2520
#define IMG_GFX_TAPE_BUTTON_INSERT_SOLUTION		2521
#define IMG_GFX_TAPE_BUTTON_PLAY_SOLUTION		2522
#define IMG_GFX_TAPE_SYMBOL_EJECT			2523
#define IMG_GFX_TAPE_SYMBOL_STOP			2524
#define IMG_GFX_TAPE_SYMBOL_PAUSE			2525
#define IMG_GFX_TAPE_SYMBOL_RECORD			2526
#define IMG_GFX_TAPE_SYMBOL_PLAY			2527
#define IMG_GFX_TAPE_SYMBOL_FAST_FORWARD		2528
#define IMG_GFX_TAPE_SYMBOL_WARP_FORWARD		2529
#define IMG_GFX_TAPE_SYMBOL_WARP_FORWARD_BLIND		2530
#define IMG_GFX_TAPE_SYMBOL_PAUSE_BEFORE_END		2531
#define IMG_GFX_TAPE_SYMBOL_SINGLE_STEP			2532
#define IMG_GFX_TAPE_LABEL_EJECT			2533
#define IMG_GFX_TAPE_LABEL_STOP				2534
#define IMG_GFX_TAPE_LABEL_PAUSE			2535
#define IMG_GFX_TAPE_LABEL_RECORD			2536
#define IMG_GFX_TAPE_LABEL_PLAY				2537
#define IMG_GFX_TAPE_LABEL_FAST_FORWARD			2538
#define IMG_GFX_TAPE_LABEL_WARP_FORWARD			2539
#define IMG_GFX_TAPE_LABEL_WARP_FORWARD_BLIND		2540
#define IMG_GFX_TAPE_LABEL_PAUSE_BEFORE_END		2541
#define IMG_GFX_TAPE_LABEL_SINGLE_STEP			2542
#define IMG_GFX_TAPE_LABEL_DATE				2543
#define IMG_GFX_TAPE_LABEL_TIME				2544
#define IMG_GFX_REQUEST_BUTTON_YES			2545
#define IMG_GFX_REQUEST_BUTTON_NO			2546
#define IMG_GFX_REQUEST_BUTTON_CONFIRM			2547
#define IMG_GFX_REQUEST_BUTTON_PLAYER_1			2548
#define IMG_GFX_REQUEST_BUTTON_PLAYER_2			2549
#define IMG_GFX_REQUEST_BUTTON_PLAYER_3			2550
#define IMG_GFX_REQUEST_BUTTON_PLAYER_4			2551
#define IMG_GFX_REQUEST_BUTTON_TOUCH_YES		2552
#define IMG_GFX_REQUEST_BUTTON_TOUCH_NO			2553
#define IMG_GFX_REQUEST_BUTTON_TOUCH_CONFIRM		2554
#define IMG_FONT_INITIAL_1				2555
#define IMG_FONT_INITIAL_2				2556
#define IMG_FONT_INITIAL_3				2557
#define IMG_FONT_INITIAL_4				2558
#define IMG_FONT_TITLE_1				2559
#define IMG_FONT_TITLE_2				2560
#define IMG_FONT_TITLE_2_SETUP				2561
#define IMG_FONT_TITLE_STORY				2562
#define IMG_FONT_FOOTER					2563
#define IMG_FONT_FOOTER_INFO				2564
#define IMG_FONT_MENU_1					2565
#define IMG_FONT_MENU_1_ACTIVE				2566
#define IMG_FONT_MENU_2					2567
#define IMG_FONT_MENU_2_ACTIVE				2568
#define IMG_FONT_TEXT_1					2569
#define IMG_FONT_TEXT_1_MAIN				2570
#define IMG_FONT_TEXT_1_LEVELS				2571
#define IMG_FONT_TEXT_1_LEVELNR				2572
#define IMG_FONT_TEXT_1_SETUP				2573
#define IMG_FONT_TEXT_1_NAMES				2574
#define IMG_FONT_TEXT_1_PREVIEW				2575
#define IMG_FONT_TEXT_1_SCORES				2576
#define IMG_FONT_TEXT_1_ACTIVE_SCORES			2577
#define IMG_FONT_TEXT_1_PANEL				2578
#define IMG_FONT_TEXT_1_DOOR				2579
#define IMG_FONT_TEXT_2					2580
#define IMG_FONT_TEXT_2_MAIN				2581
#define IMG_FONT_TEXT_2_LEVELS				2582
#define IMG_FONT_TEXT_2_LEVELNR				2583
#define IMG_FONT_TEXT_2_SETUP				2584
#define IMG_FONT_TEXT_2_NAMES				2585
#define IMG_FONT_TEXT_2_PREVIEW				2586
#define IMG_FONT_TEXT_2_SCORES				2587
#define IMG_FONT_TEXT_2_ACTIVE_SCORES			2588
#define IMG_FONT_TEXT_3					2589
#define IMG_FONT_TEXT_3_LEVELS				2590
#define IMG_FONT_TEXT_3_LEVELNR				2591
#define IMG_FONT_TEXT_3_SETUP				2592
#define IMG_FONT_TEXT_3_NAMES				2593
#define IMG_FONT_TEXT_3_PREVIEW				2594
#define IMG_FONT_TEXT_3_SCORES				2595
#define IMG_FONT_TEXT_3_ACTIVE_SCORES			2596
#define IMG_FONT_TEXT_4					2597
#define IMG_FONT_TEXT_4_MAIN				2598
#define IMG_FONT_TEXT_4_LEVELS				2599
#define IMG_FONT_TEXT_4_LEVELNR				2600
#define IMG_FONT_TEXT_4_SETUP				2601
#define IMG_FONT_TEXT_4_NAMES				2602
#define IMG_FONT_TEXT_4_INFO				2603
#define IMG_FONT_TEXT_4_SCORES				2604
#define IMG_FONT_TEXT_4_ACTIVE_SCORES			2605
#define IMG_FONT_ENVELOPE_1				2606
#define IMG_FONT_ENVELOPE_2				2607
#define IMG_FONT_ENVELOPE_3				2608
#define IMG_FONT_ENVELOPE_4				2609
#define IMG_FONT_REQUEST				2610
#define IMG_FONT_REQUEST_NARROW				2611
#define IMG_FONT_INPUT_1				2612
#define IMG_FONT_INPUT_1_MAIN				2613
#define IMG_FONT_INPUT_1_NAMES				2614
#define IMG_FONT_INPUT_1_ACTIVE				2615
#define IMG_FONT_INPUT_1_ACTIVE_MAIN			2616
#define IMG_FONT_INPUT_1_ACTIVE_NAMES			2617
#define IMG_FONT_INPUT_1_ACTIVE_SETUP			2618
#define IMG_FONT_INPUT_2				2619
#define IMG_FONT_INPUT_2_ACTIVE				2620
#define IMG_FONT_OPTION_OFF				2621
#define IMG_FONT_OPTION_OFF_NARROW			2622
#define IMG_FONT_OPTION_ON				2623
#define IMG_FONT_OPTION_ON_NARROW			2624
#define IMG_FONT_VALUE_1				2625
#define IMG_FONT_VALUE_2				2626
#define IMG_FONT_VALUE_OLD				2627
#define IMG_FONT_VALUE_OLD_NARROW			2628
#define IMG_FONT_VALUE_NARROW				2629
#define IMG_FONT_LEVEL_NUMBER				2630
#define IMG_FONT_LEVEL_NUMBER_ACTIVE			2631
#define IMG_FONT_TAPE_RECORDER				2632
#define IMG_FONT_GAME_INFO				2633
#define IMG_FONT_INFO_ELEMENTS				2634
#define IMG_FONT_INFO_LEVELSET				2635
#define IMG_FONT_INFO_LEVEL				2636
#define IMG_FONT_INFO_STORY				2637
#define IMG_FONT_MAIN_NETWORK_PLAYERS			2638
#define IMG_FONT_TOOLTIP				2639
#define IMG_EDITOR_ELEMENT_BORDER			2640
#define IMG_EDITOR_ELEMENT_BORDER_INPUT			2641
#define IMG_EDITOR_COUNTER_DOWN				2642
#define IMG_EDITOR_COUNTER_UP				2643
#define IMG_EDITOR_COUNTER_INPUT			2644
#define IMG_EDITOR_SELECTBOX_INPUT			2645
#define IMG_EDITOR_SELECTBOX_BUTTON			2646
#define IMG_EDITOR_CHECKBOX				2647
#define IMG_EDITOR_RADIOBUTTON				2648
#define IMG_EDITOR_STICKYBUTTON				2649
#define IMG_EDITOR_TABBUTTON				2650
#define IMG_EDITOR_TEXTBUTTON				2651
#define IMG_EDITOR_INPUT_TEXT				2652
#define IMG_EDITOR_INPUT_TEXTAREA			2653
#define IMG_EDITOR_INPUT_COLORPICKER			2654
#define IMG_EDITOR_CASCADE_LIST				2655
#define IMG_EDITOR_CASCADE_LIST_ACTIVE			2656
#define IMG_EDITOR_PALETTE_BUTTON			2657
#define IMG_EDITOR_PALETTE_SCROLL_UP			2658
#define IMG_EDITOR_PALETTE_SCROLL_DOWN			2659
#define IMG_EDITOR_PALETTE_SCROLLBAR			2660
#define IMG_EDITOR_PLAYFIELD_SCROLL_UP			2661
#define IMG_EDITOR_PLAYFIELD_SCROLL_DOWN		2662
#define IMG_EDITOR_PLAYFIELD_SCROLL_LEFT		2663
#define IMG_EDITOR_PLAYFIELD_SCROLL_RIGHT		2664
#define IMG_EDITOR_PLAYFIELD_SCROLLBAR			2665
#define IMG_EDITOR_INFOTEXT_SCROLL_UP			2666
#define IMG_EDITOR_INFOTEXT_SCROLL_DOWN			2667
#define IMG_EDITOR_INFOTEXT_SCROLLBAR			2668
#define IMG_GFX_EDITOR_BUTTON_PREV_LEVEL		2669
#define IMG_GFX_EDITOR_BUTTON_NEXT_LEVEL		2670
#define IMG_GFX_EDITOR_BUTTON_PROPERTIES		2671
#define IMG_GFX_EDITOR_BUTTON_ELEMENT_LEFT		2672
#define IMG_GFX_EDITOR_BUTTON_ELEMENT_MIDDLE		2673
#define IMG_GFX_EDITOR_BUTTON_ELEMENT_RIGHT		2674
#define IMG_GFX_EDITOR_BUTTON_PALETTE			2675
#define IMG_EDITOR_NO_TOOLBOX_BUTTON			2676
#define IMG_GFX_EDITOR_BUTTON_DRAW_SINGLE		2677
#define IMG_GFX_EDITOR_BUTTON_DRAW_CONNECTED		2678
#define IMG_GFX_EDITOR_BUTTON_DRAW_LINE			2679
#define IMG_GFX_EDITOR_BUTTON_DRAW_ARC			2680
#define IMG_GFX_EDITOR_BUTTON_DRAW_RECTANGLE		2681
#define IMG_GFX_EDITOR_BUTTON_DRAW_FILLED_BOX		2682
#define IMG_GFX_EDITOR_BUTTON_ROTATE_UP			2683
#define IMG_GFX_EDITOR_BUTTON_DRAW_TEXT			2684
#define IMG_GFX_EDITOR_BUTTON_FLOOD_FILL		2685
#define IMG_GFX_EDITOR_BUTTON_ROTATE_LEFT		2686
#define IMG_GFX_EDITOR_BUTTON_ZOOM_LEVEL		2687
#define IMG_GFX_EDITOR_BUTTON_ROTATE_RIGHT		2688
#define IMG_GFX_EDITOR_BUTTON_DRAW_RANDOM		2689
#define IMG_GFX_EDITOR_BUTTON_GRAB_BRUSH		2690
#define IMG_GFX_EDITOR_BUTTON_ROTATE_DOWN		2691
#define IMG_GFX_EDITOR_BUTTON_PICK_ELEMENT		2692
#define IMG_GFX_EDITOR_BUTTON_CE_COPY_FROM		2693
#define IMG_GFX_EDITOR_BUTTON_CE_COPY_TO		2694
#define IMG_GFX_EDITOR_BUTTON_CE_SWAP			2695
#define IMG_GFX_EDITOR_BUTTON_CE_COPY			2696
#define IMG_GFX_EDITOR_BUTTON_CE_PASTE			2697
#define IMG_GFX_EDITOR_BUTTON_CP_COPY			2698
#define IMG_GFX_EDITOR_BUTTON_CP_PASTE			2699
#define IMG_GFX_EDITOR_BUTTON_UNDO			2700
#define IMG_GFX_EDITOR_BUTTON_CONF			2701
#define IMG_GFX_EDITOR_BUTTON_SAVE			2702
#define IMG_GFX_EDITOR_BUTTON_CLEAR			2703
#define IMG_GFX_EDITOR_BUTTON_TEST			2704
#define IMG_GFX_EDITOR_BUTTON_EXIT			2705
#define IMG_GFX_EDITOR_INPUT_LEVEL_NUMBER		2706
#define IMG_SETUP_INPUT_TEXT				2707
#define IMG_GLOBAL_BORDER				2708
#define IMG_GLOBAL_BORDER_MAIN				2709
#define IMG_GLOBAL_BORDER_SCORES			2710
#define IMG_GLOBAL_BORDER_EDITOR			2711
#define IMG_GLOBAL_BORDER_PLAYING			2712
#define IMG_GLOBAL_DOOR					2713
#define IMG_GLOBAL_BUSY_INITIAL				2714
#define IMG_GLOBAL_BUSY					2715
#define IMG_GLOBAL_BUSY_PLAYFIELD			2716
#define IMG_GLOBAL_TILE_CURSOR				2717
#define IMG_BACKGROUND					2718
#define IMG_BACKGROUND_LOADING_INITIAL			2719
#define IMG_BACKGROUND_LOADING				2720
#define IMG_BACKGROUND_TITLE_INITIAL			2721
#define IMG_BACKGROUND_TITLE				2722
#define IMG_BACKGROUND_MAIN				2723
#define IMG_BACKGROUND_NAMES				2724
#define IMG_BACKGROUND_LEVELS				2725
#define IMG_BACKGROUND_LEVELNR				2726
#define IMG_BACKGROUND_SCORES				2727
#define IMG_BACKGROUND_SCOREINFO			2728
#define IMG_BACKGROUND_EDITOR				2729
#define IMG_BACKGROUND_INFO				2730
#define IMG_BACKGROUND_INFO_ELEMENTS			2731
#define IMG_BACKGROUND_INFO_MUSIC			2732
#define IMG_BACKGROUND_INFO_CREDITS			2733
#define IMG_BACKGROUND_INFO_PROGRAM			2734
#define IMG_BACKGROUND_INFO_VERSION			2735
#define IMG_BACKGROUND_INFO_LEVELSET			2736
#define IMG_BACKGROUND_INFO_LEVEL			2737
#define IMG_BACKGROUND_STORY				2738
#define IMG_BACKGROUND_SETUP				2739
#define IMG_BACKGROUND_PLAYING				2740
#define IMG_BACKGROUND_DOOR				2741
#define IMG_BACKGROUND_TAPE				2742
#define IMG_BACKGROUND_PANEL				2743
#define IMG_BACKGROUND_PALETTE				2744
#define IMG_BACKGROUND_TOOLBOX				2745
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_1		2746
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_2		2747
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_3		2748
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_4		2749
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_5		2750
#define IMG_BACKGROUND_TITLESCREEN_1			2751
#define IMG_BACKGROUND_TITLESCREEN_2			2752
#define IMG_BACKGROUND_TITLESCREEN_3			2753
#define IMG_BACKGROUND_TITLESCREEN_4			2754
#define IMG_BACKGROUND_TITLESCREEN_5			2755
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_1		2756
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_2		2757
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_3		2758
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_4		2759
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_5		2760
#define IMG_BACKGROUND_TITLEMESSAGE_1			2761
#define IMG_BACKGROUND_TITLEMESSAGE_2			2762
#define IMG_BACKGROUND_TITLEMESSAGE_3			2763
#define IMG_BACKGROUND_TITLEMESSAGE_4			2764
#define IMG_BACKGROUND_TITLEMESSAGE_5			2765
#define IMG_BACKGROUND_ENVELOPE_1			2766
#define IMG_BACKGROUND_ENVELOPE_2			2767
#define IMG_BACKGROUND_ENVELOPE_3			2768
#define IMG_BACKGROUND_ENVELOPE_4			2769
#define IMG_BACKGROUND_REQUEST				2770
#define IMG_TITLESCREEN_INITIAL_1			2771
#define IMG_TITLESCREEN_INITIAL_2			2772
#define IMG_TITLESCREEN_INITIAL_3			2773
#define IMG_TITLESCREEN_INITIAL_4			2774
#define IMG_TITLESCREEN_INITIAL_5			2775
#define IMG_TITLESCREEN_1				2776
#define IMG_TITLESCREEN_2				2777
#define IMG_TITLESCREEN_3				2778
#define IMG_TITLESCREEN_4				2779
#define IMG_TITLESCREEN_5				2780
#define IMG_GFX_DOOR_1_PART_1				2781
#define IMG_GFX_DOOR_1_PART_2				2782
#define IMG_GFX_DOOR_1_PART_3				2783
#define IMG_GFX_DOOR_1_PART_4				2784
#define IMG_GFX_DOOR_1_PART_5				2785
#define IMG_GFX_DOOR_1_PART_6				2786
#define IMG_GFX_DOOR_1_PART_7				2787
#define IMG_GFX_DOOR_1_PART_8				2788
#define IMG_GFX_DOOR_2_PART_1				2789
#define IMG_GFX_DOOR_2_PART_2				2790
#define IMG_GFX_DOOR_2_PART_3				2791
#define IMG_GFX_DOOR_2_PART_4				2792
#define IMG_GFX_DOOR_2_PART_5				2793
#define IMG_GFX_DOOR_2_PART_6				2794
#define IMG_GFX_DOOR_2_PART_7				2795
#define IMG_GFX_DOOR_2_PART_8				2796
#define IMG_DOOR_2_TOP_BORDER_CORRECTION		2797
#define IMG_LAST_IMAGE_ENTRY_BUG			2798

#define NUM_IMAGE_FILES					2799

#endif	// CONF_GFX_H
